/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class GitHubApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Organization = new OrganizationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Release = new ReleaseGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Pull = new PullGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Repository = new RepositoryGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Deployment = new DeploymentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Branch = new BranchGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Git = new GitGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Commit = new CommitGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Issue = new IssueGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Project = new ProjectGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Search = new SearchGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Organization, this.Release, this.User, this.Pull, this.Repository, this.Deployment, this.Branch, this.Git, this.Commit, this.Issue, this.Project, this.Search);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Organization, Release, User, Pull, Repository, Deployment, Branch, Git, Commit, Issue, Project, Search) {
        this.Organization = Organization;
        this.Release = Release;
        this.User = User;
        this.Pull = Pull;
        this.Repository = Repository;
        this.Deployment = Deployment;
        this.Branch = Branch;
        this.Git = Git;
        this.Commit = Commit;
        this.Issue = Issue;
        this.Project = Project;
        this.Search = Search;
    }
    /**
  * Lists all organizations, in the order that they were created on GitHub.
  
  **Note:** Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of organizations.
  * Alternative usage: Organization.getOrganizations
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations
  * @param options Request options.
  */
    async getOrganizations(options) {
        return this.Organization.getOrganizations(options);
    }
    /**
  * To see many of the organization response values, you need to be an authenticated organization owner with the `admin:org` scope. When the value of `two_factor_requirement_enabled` is `true`, the organization requires all members, billing managers, and outside collaborators to enable [two-factor authentication](https://docs.github.com/articles/securing-your-account-with-two-factor-authentication-2fa/).
  
  GitHub Apps with the `Organization plan` permission can use this endpoint to retrieve information about an organization's GitHub plan. See "[Authenticating with GitHub Apps](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/)" for details. For an example response, see 'Response with GitHub plan information' below."
  * Alternative usage: Organization.getOrganization
  * Documentation: https://docs.github.com/en/rest/reference/orgs#get-an-organization
  * @param options Request options.
  */
    async getOrganization(options) {
        return this.Organization.getOrganization(options);
    }
    /**
  * **Parameter Deprecation Notice:** GitHub will replace and discontinue `members_allowed_repository_creation_type` in favor of more granular permissions. The new input parameters are `members_can_create_public_repositories`, `members_can_create_private_repositories` for all organizations and `members_can_create_internal_repositories` for organizations associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+. For more information, see the [blog post](https://developer.github.com/changes/2019-12-03-internal-visibility-changes).
  
  Enables an authenticated organization owner with the `admin:org` scope to update the organization's profile and member privileges.
  * Alternative usage: Organization.updateOrganization
  * Documentation: https://docs.github.com/en/rest/reference/orgs#update-an-organization
  * @param options Request options.
  */
    async updateOrganization(options) {
        return this.Organization.updateOrganization(options);
    }
    /**
     * Lists all GitHub Apps in an organization. The installation count includes all GitHub Apps installed on repositories in the organization. You must be an organization owner with `admin:read` scope to use this endpoint.
     * Alternative usage: Organization.getInstallations
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-app-installations-for-an-organization
     * @param options Request options.
     */
    async getInstallationsForOrganization(options) {
        return this.Organization.getInstallations(options);
    }
    /**
  * List organizations for the authenticated user.
  
  **OAuth scope requirements**
  
  This only lists organizations that your authorization allows you to operate on in some way (e.g., you can list teams with `read:org` scope, you can publicize your organization membership with `user` scope, etc.). Therefore, this API requires at least `user` or `read:org` scope. OAuth requests with insufficient scope receive a `403 Forbidden` response.
  * Alternative usage: Organization.getOrganizationsForAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations-for-the-authenticated-user
  * @param options Request options.
  */
    async getOrganizationsForAuthenticatedUser(options) {
        return this.Organization.getOrganizationsForAuthenticatedUser(options);
    }
    /**
  * List [public organization memberships](https://docs.github.com/articles/publicizing-or-concealing-organization-membership) for the specified user.
  
  This method only lists _public_ memberships, regardless of authentication. If you need to fetch all of the organization memberships (public and private) for the authenticated user, use the [List organizations for the authenticated user](https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user) API instead.
  * Alternative usage: Organization.getOrganizationsForUser
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations-for-a-user
  * @param options Request options.
  */
    async getOrganizationsForUser(options) {
        return this.Organization.getOrganizationsForUser(options);
    }
    /**
     * List all users who are members of an organization. If the authenticated user is also a member of this organization then both concealed and public members will be returned.
     * Alternative usage: Organization.Member.getMembers
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organization-members
     * @param options Request options.
     */
    async getOrganizationMembers(options) {
        return this.Organization.Member.getMembers(options);
    }
    /**
     * Check if a user is, publicly or privately, a member of the organization.
     * Alternative usage: Organization.Member.checkMembershipForUser
     * Documentation: https://docs.github.com/en/rest/reference/orgs#check-organization-membership-for-a-user
     * @param options Request options.
     */
    async checkOrganizationMembershipForUser(options) {
        return this.Organization.Member.checkMembershipForUser(options);
    }
    /**
     * Removing a user from this list will remove them from all teams and they will no longer have any access to the organization's repositories.
     * Alternative usage: Organization.Member.removeMember
     * Documentation: https://docs.github.com/en/rest/reference/orgs#remove-an-organization-member
     * @param options Request options.
     */
    async removeOrganizationMember(options) {
        return this.Organization.Member.removeMember(options);
    }
    /**
     * In order to get a user's membership with an organization, the authenticated user must be an organization member. The `state` parameter in the response can be used to identify the user's membership status.
     * Alternative usage: Organization.Member.getMembershipForUser
     * Documentation: https://docs.github.com/en/rest/reference/orgs#get-organization-membership-for-a-user
     * @param options Request options.
     */
    async getOrganizationMembershipForUser(options) {
        return this.Organization.Member.getMembershipForUser(options);
    }
    /**
  * Only authenticated organization owners can add a member to the organization or update the member's role.
  
  *   If the authenticated user is _adding_ a member to the organization, the invited user will receive an email inviting them to the organization. The user's [membership status](https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user) will be `pending` until they accept the invitation.
      
  *   Authenticated users can _update_ a user's membership by passing the `role` parameter. If the authenticated user changes a member's role to `admin`, the affected user will receive an email notifying them that they've been made an organization owner. If the authenticated user changes an owner's role to `member`, no email will be sent.
  
  **Rate limits**
  
  To prevent abuse, the authenticated user is limited to 50 organization invitations per 24 hour period. If the organization is more than one month old or on a paid plan, the limit is 500 invitations per 24 hour period.
  * Alternative usage: Organization.Member.setMembershipForUser
  * Documentation: https://docs.github.com/en/rest/reference/orgs#set-organization-membership-for-a-user
  * @param options Request options.
  */
    async setOrganizationMembershipForUser(options) {
        return this.Organization.Member.setMembershipForUser(options);
    }
    /**
  * In order to remove a user's membership with an organization, the authenticated user must be an organization owner.
  
  If the specified user is an active member of the organization, this will remove them from the organization. If the specified user has been invited to the organization, this will cancel their invitation. The specified user will receive an email notification in both cases.
  * Alternative usage: Organization.Member.removeMembershipForUser
  * Documentation: https://docs.github.com/en/rest/reference/orgs#remove-organization-membership-for-a-user
  * @param options Request options.
  */
    async removeOrganzationMembershipForUser(options) {
        return this.Organization.Member.removeMembershipForUser(options);
    }
    /**
     *
     * Alternative usage: Organization.Member.getMembershipsForAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user
     * @param options Request options.
     */
    async getOrganizationMembershipsForAuthenticatedUser(options) {
        return this.Organization.Member.getMembershipsForAuthenticatedUser(options);
    }
    /**
     *
     * Alternative usage: Organization.Member.getMembershipForAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/orgs#get-an-organization-membership-for-the-authenticated-user
     * @param options Request options.
     */
    async getOrganizationMembershipForAuthenticatedUser(options) {
        return this.Organization.Member.getMembershipForAuthenticatedUser(options);
    }
    /**
     *
     * Alternative usage: Organization.Member.updateMembershipForAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/orgs#update-an-organization-membership-for-the-authenticated-user
     * @param options Request options.
     */
    async updateOrganizationMembershipForAuthenticatedUser(options) {
        return this.Organization.Member.updateMembershipForAuthenticatedUser(options);
    }
    /**
  * This returns a list of releases, which does not include regular Git tags that have not been associated with a release. To get a list of Git tags, use the [Repository Tags API](https://docs.github.com/rest/reference/repos#list-repository-tags).
  
  Information about published releases are available to everyone. Only users with push access will receive listings for draft releases.
  * Alternative usage: Release.getReleases
  * Documentation: https://docs.github.com/en/rest/reference/releases#list-releases
  * @param options Request options.
  */
    async getReleases(options) {
        return this.Release.getReleases(options);
    }
    /**
  * Users with push access to the repository can create a release.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Alternative usage: Release.createRelease
  * Documentation: https://docs.github.com/en/rest/reference/releases#create-a-release
  * @param options Request options.
  */
    async createRelease(options) {
        return this.Release.createRelease(options);
    }
    /**
     * Generate a name and body describing a [release](https://docs.github.com/rest/reference/repos#releases). The body content will be markdown formatted and contain information like the changes since last release and users who contributed. The generated release notes are not saved anywhere. They are intended to be generated and used when creating a new release.
     * Alternative usage: Release.generateReleaseNotes
     * Documentation: https://docs.github.com/en/rest/reference/releases#generate-release-notes-content-for-a-release
     * @param options Request options.
     */
    async generateReleaseNotes(options) {
        return this.Release.generateReleaseNotes(options);
    }
    /**
  * View the latest published full release for the repository.
  
  The latest release is the most recent non-prerelease, non-draft release, sorted by the `created_at` attribute. The `created_at` attribute is the date of the commit used for the release, and not the date when the release was drafted or published.
  * Alternative usage: Release.getLatestRelease
  * Documentation: https://docs.github.com/en/rest/reference/releases#get-the-latest-release
  * @param options Request options.
  */
    async getLatestRelease(options) {
        return this.Release.getLatestRelease(options);
    }
    /**
     * Get a published release with the specified tag.
     * Alternative usage: Release.getReleaseByTagName
     * Documentation: https://docs.github.com/en/rest/reference/releases#get-a-release-by-tag-name
     * @param options Request options.
     */
    async getReleaseByTagName(options) {
        return this.Release.getReleaseByTagName(options);
    }
    /**
     * **Note:** This returns an `upload_url` key corresponding to the endpoint for uploading release assets. This key is a [hypermedia resource](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia).
     * Alternative usage: Release.getRelease
     * Documentation: https://docs.github.com/en/rest/reference/releases#get-a-release
     * @param options Request options.
     */
    async getRelease(options) {
        return this.Release.getRelease(options);
    }
    /**
     * Users with push access to the repository can edit a release.
     * Alternative usage: Release.updateRelease
     * Documentation: https://docs.github.com/en/rest/reference/releases#update-a-release
     * @param options Request options.
     */
    async updateRelease(options) {
        return this.Release.updateRelease(options);
    }
    /**
     * Users with push access to the repository can delete a release.
     * Alternative usage: Release.deleteRelease
     * Documentation: https://docs.github.com/en/rest/reference/releases#delete-a-release
     * @param options Request options.
     */
    async deleteRelease(options) {
        return this.Release.deleteRelease(options);
    }
    /**
  * If the authenticated user is authenticated through basic authentication or OAuth with the `user` scope, then the response lists public and private profile information.
  
  If the authenticated user is authenticated through OAuth without the `user` scope, then the response lists only public profile information.
  * Alternative usage: User.getAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/users#get-the-authenticated-user
  * @param options Request options.
  */
    async getAuthenticatedUser(options) {
        return this.User.getAuthenticatedUser(options);
    }
    /**
     * **Note:** If your email is set to private and you send an `email` parameter as part of this request to update your profile, your privacy settings are still enforced: the email address will not be displayed on your public profile or via the API.
     * Alternative usage: User.updateAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/users#update-the-authenticated-user
     * @param options Request options.
     */
    async updateAuthenticatedUser(options) {
        return this.User.updateAuthenticatedUser(options);
    }
    /**
  * Lists all users, in the order that they signed up on GitHub. This list includes personal user accounts and organization accounts.
  
  Note: Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of users.
  * Alternative usage: User.getUsers
  * Documentation: https://docs.github.com/en/rest/reference/users#list-users
  * @param options Request options.
  */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
  * Provides publicly available information about someone with a GitHub account.
  
  GitHub Apps with the `Plan` user permission can use this endpoint to retrieve information about a user's GitHub plan. The GitHub App must be authenticated as a user. See "[Identifying and authorizing users for GitHub Apps](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/)" for details about authentication. For an example response, see 'Response with GitHub plan information' below"
  
  The `email` key in the following response is the publicly visible email address from your GitHub [profile page](https://github.com/settings/profile). When setting up your profile, you can select a primary email address to be “public” which provides an email entry for this endpoint. If you do not set a public email address for `email`, then it will have a value of `null`. You only see publicly visible email addresses when authenticated with GitHub. For more information, see [Authentication](https://docs.github.com/rest/overview/resources-in-the-rest-api#authentication).
  
  The Emails API enables you to list all of your email addresses, and toggle a primary email to be visible publicly. For more information, see "[Emails API](https://docs.github.com/rest/reference/users#emails)".
  * Alternative usage: User.getUser
  * Documentation: https://docs.github.com/en/rest/reference/users#get-a-user
  * @param options Request options.
  */
    async getUser(options) {
        return this.User.getUser(options);
    }
    /**
  * Provides hovercard information when authenticated through basic auth or OAuth with the `repo` scope. You can find out more about someone in relation to their pull requests, issues, repositories, and organizations.
  
  The `subject_type` and `subject_id` parameters provide context for the person's hovercard, which returns more information than without the parameters. For example, if you wanted to find out more about `octocat` who owns the `Spoon-Knife` repository via cURL, it would look like this:
  
  ```shell
   curl -u username:token
    https://api.github.com/users/octocat/hovercard?subject_type=repository&subject_id=1300192
  ```
  * Alternative usage: User.getUserContext
  * Documentation: https://docs.github.com/en/rest/reference/users#get-contextual-information-for-a-user
  * @param options Request options.
  */
    async getUserContext(options) {
        return this.User.getUserContext(options);
    }
    /**
     * List the users you've blocked on your personal account.
     * Alternative usage: User.Block.getBlockedUsersByAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/users#list-users-blocked-by-the-authenticated-user
     * @param options Request options.
     */
    async getBlockedUsersByAuthenticatedUser(options) {
        return this.User.Block.getBlockedUsersByAuthenticatedUser(options);
    }
    /**
     *
     * Alternative usage: User.Block.checkIfUserIsBlockedByAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/users#check-if-a-user-is-blocked-by-the-authenticated-user
     * @param options Request options.
     */
    async checkIfUserIsBlockedByAuthenticatedUser(options) {
        return this.User.Block.checkIfUserIsBlockedByAuthenticatedUser(options);
    }
    /**
     *
     * Alternative usage: User.Block.blockUser
     * Documentation: https://docs.github.com/en/rest/reference/users#block-a-user
     * @param options Request options.
     */
    async blockUser(options) {
        return this.User.Block.blockUser(options);
    }
    /**
     *
     * Alternative usage: User.Block.unblockUser
     * Documentation: https://docs.github.com/en/rest/reference/users#unblock-a-user
     * @param options Request options.
     */
    async unblockUser(options) {
        return this.User.Block.unblockUser(options);
    }
    /**
     * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Pull.getPullRequests
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-pull-requests
     * @param options Request options.
     */
    async getPullRequests(options) {
        return this.Pull.getPullRequests(options);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-rate-limits)" for details.
  * Alternative usage: Pull.createPullRequest
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-pull-request
  * @param options Request options.
  */
    async createPullRequest(options) {
        return this.Pull.createPullRequest(options);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Lists details of a pull request by providing its number.
  
  When you get, [create](https://docs.github.com/rest/reference/pulls/#create-a-pull-request), or [edit](https://docs.github.com/rest/reference/pulls#update-a-pull-request) a pull request, GitHub creates a merge commit to test whether the pull request can be automatically merged into the base branch. This test commit is not added to the base branch or the head branch. You can review the status of the test commit using the `mergeable` key. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  
  The value of the `mergeable` attribute can be `true`, `false`, or `null`. If the value is `null`, then GitHub has started a background job to compute the mergeability. After giving the job time to complete, resubmit the request. When the job finishes, you will see a non-`null` value for the `mergeable` attribute in the response. If `mergeable` is `true`, then `merge_commit_sha` will be the SHA of the _test_ merge commit.
  
  The value of the `merge_commit_sha` attribute changes depending on the state of the pull request. Before merging a pull request, the `merge_commit_sha` attribute holds the SHA of the _test_ merge commit. After merging a pull request, the `merge_commit_sha` attribute changes depending on how you merged the pull request:
  
  *   If merged as a [merge commit](https://docs.github.com/articles/about-merge-methods-on-github/), `merge_commit_sha` represents the SHA of the merge commit.
  *   If merged via a [squash](https://docs.github.com/articles/about-merge-methods-on-github/#squashing-your-merge-commits), `merge_commit_sha` represents the SHA of the squashed commit on the base branch.
  *   If [rebased](https://docs.github.com/articles/about-merge-methods-on-github/#rebasing-and-merging-your-commits), `merge_commit_sha` represents the commit that the base branch was updated to.
  
  Pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
  * Alternative usage: Pull.getPullRequest
  * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-pull-request
  * @param options Request options.
  */
    async getPullRequest(options) {
        return this.Pull.getPullRequest(options);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
  * Alternative usage: Pull.updatePullRequest
  * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-pull-request
  * @param options Request options.
  */
    async updatePullRequest(options) {
        return this.Pull.updatePullRequest(options);
    }
    /**
     * Lists a maximum of 250 commits for a pull request. To receive a complete commit list for pull requests with more than 250 commits, use the [List commits](https://docs.github.com/rest/reference/repos#list-commits) endpoint.
     * Alternative usage: Pull.getCommits
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-commits-on-a-pull-request
     * @param options Request options.
     */
    async getPullRequestCommits(options) {
        return this.Pull.getCommits(options);
    }
    /**
     * **Note:** Responses include a maximum of 3000 files. The paginated response returns 30 files per page by default.
     * Alternative usage: Pull.getFiles
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-pull-requests-files
     * @param options Request options.
     */
    async getPullRequestFiles(options) {
        return this.Pull.getFiles(options);
    }
    /**
     *
     * Alternative usage: Pull.isMerged
     * Documentation: https://docs.github.com/en/rest/reference/pulls#check-if-a-pull-request-has-been-merged
     * @param options Request options.
     */
    async isPullRequestMerged(options) {
        return this.Pull.isMerged(options);
    }
    /**
     * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
     * Alternative usage: Pull.mergePullRequest
     * Documentation: https://docs.github.com/en/rest/reference/pulls#merge-a-pull-request
     * @param options Request options.
     */
    async mergePullRequest(options) {
        return this.Pull.mergePullRequest(options);
    }
    /**
     * Updates the pull request branch with the latest upstream changes by merging HEAD from the base branch into the pull request branch.
     * Alternative usage: Pull.updatePullRequestBranch
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-pull-request-branch
     * @param options Request options.
     */
    async updatePullRequestBranch(options) {
        return this.Pull.updatePullRequestBranch(options);
    }
    /**
     * The list of reviews returns in chronological order.
     * Alternative usage: Pull.Review.getReviews
     * Documentation: https://docs.github.com/en/rest/reference/pulls#reviews
     * @param options Request options.
     */
    async getPullRequestReviews(options) {
        return this.Pull.Review.getReviews(options);
    }
    /**
  * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  
  Pull request reviews created in the `PENDING` state are not submitted and therefore do not include the `submitted_at` property in the response. To create a pending review for a pull request, leave the `event` parameter blank. For more information about submitting a `PENDING` review, see "[Submit a review for a pull request](https://docs.github.com/rest/pulls#submit-a-review-for-a-pull-request)."
  
  **Note:** To comment on a specific line in a file, you need to first determine the _position_ of that line in the diff. The GitHub REST API offers the `application/vnd.github.v3.diff` [media type](https://docs.github.com/rest/overview/media-types#commits-commit-comparison-and-pull-requests). To see a pull request diff, add this media type to the `Accept` header of a call to the [single pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) endpoint.
  
  The `position` value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
  * Alternative usage: Pull.Review.createReview
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-review-for-a-pull-request
  * @param options Request options.
  */
    async createPullRequestReview(options) {
        return this.Pull.Review.createReview(options);
    }
    /**
     *
     * Alternative usage: Pull.Review.getReview
     * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-review-for-a-pull-request
     * @param options Request options.
     */
    async getPullRequestReview(options) {
        return this.Pull.Review.getReview(options);
    }
    /**
     * Update the review summary comment with new text.
     * Alternative usage: Pull.Review.updateReview
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-review-for-a-pull-request
     * @param options Request options.
     */
    async updatePullRequestReview(options) {
        return this.Pull.Review.updateReview(options);
    }
    /**
     *
     * Alternative usage: Pull.Review.deletePendingReview
     * Documentation: https://docs.github.com/en/rest/reference/pulls#delete-a-pending-review-for-a-pull-request
     * @param options Request options.
     */
    async deletePullRequestReview(options) {
        return this.Pull.Review.deletePendingReview(options);
    }
    /**
     * List comments for a specific pull request review.
     * Alternative usage: Pull.Review.getComments
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-comments-for-a-pull-request-review
     * @param options Request options.
     */
    async getCommentsForPullRequestReview(options) {
        return this.Pull.Review.getComments(options);
    }
    /**
     * **Note:** To dismiss a pull request review on a [protected branch](https://docs.github.com/rest/reference/repos#branches), you must be a repository administrator or be included in the list of people or teams who can dismiss pull request reviews.
     * Alternative usage: Pull.Review.dismissReview
     * Documentation: https://docs.github.com/en/rest/reference/pulls#dismiss-a-review-for-a-pull-request
     * @param options Request options.
     */
    async dismissPullRequestReview(options) {
        return this.Pull.Review.dismissReview(options);
    }
    /**
     * Submits a pending review for a pull request. For more information about creating a pending review for a pull request, see "[Create a review for a pull request](https://docs.github.com/rest/pulls#create-a-review-for-a-pull-request)."
     * Alternative usage: Pull.Review.submitReview
     * Documentation: https://docs.github.com/en/rest/reference/pulls#submit-a-review-for-a-pull-request
     * @param options Request options.
     */
    async submitPullRequestReview(options) {
        return this.Pull.Review.submitReview(options);
    }
    /**
     * Gets the users or teams whose review is requested for a pull request. Once a requested reviewer submits a review, they are no longer considered a requested reviewer. Their review will instead be returned by the [List reviews for a pull request](https://docs.github.com/rest/pulls/reviews#list-reviews-for-a-pull-request) operation.
     * Alternative usage: Pull.Review.Request.getReviewers
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-requested-reviewers-for-a-pull-request
     * @param options Request options.
     */
    async getPullRequestReviewers(options) {
        return this.Pull.Review.Request.getReviewers(options);
    }
    /**
     * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
     * Alternative usage: Pull.Review.Request.requestReviewers
     * Documentation: https://docs.github.com/en/rest/reference/pulls#request-reviewers-for-a-pull-request
     * @param options Request options.
     */
    async requestReviewersForPullRequest(options) {
        return this.Pull.Review.Request.requestReviewers(options);
    }
    /**
     *
     * Alternative usage: Pull.Review.Request.removeReviewers
     * Documentation: https://docs.github.com/en/rest/reference/pulls#remove-requested-reviewers-from-a-pull-request
     * @param options Request options.
     */
    async removePullRequestReviewers(options) {
        return this.Pull.Review.Request.removeReviewers(options);
    }
    /**
     * Lists review comments for all pull requests in a repository. By default, review comments are in ascending order by ID.
     * Alternative usage: Pull.Review.Comment.getCommentsInRepository
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-review-comments-in-a-repository
     * @param options Request options.
     */
    async getPullRequestReviewCommentInRepository(options) {
        return this.Pull.Review.Comment.getCommentsInRepository(options);
    }
    /**
     * Provides details for a review comment.
     * Alternative usage: Pull.Review.Comment.getComment
     * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async getPullRequestReviewComment(options) {
        return this.Pull.Review.Comment.getComment(options);
    }
    /**
     * Enables you to edit a review comment.
     * Alternative usage: Pull.Review.Comment.updateComment
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async updatePullRequestReviewComment(options) {
        return this.Pull.Review.Comment.updateComment(options);
    }
    /**
     * Deletes a review comment.
     * Alternative usage: Pull.Review.Comment.deleteComment
     * Documentation: https://docs.github.com/en/rest/reference/pulls#delete-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async deletePullRequestReviewComment(options) {
        return this.Pull.Review.Comment.deleteComment(options);
    }
    /**
     * Lists all review comments for a pull request. By default, review comments are in ascending order by ID.
     * Alternative usage: Pull.Review.Comment.getComments
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-review-comments-on-a-pull-request
     * @param options Request options.
     */
    async getPullRequestReviewComments(options) {
        return this.Pull.Review.Comment.getComments(options);
    }
    /**
  *
  Creates a review comment in the pull request diff. To add a regular comment to a pull request timeline, see "[Create an issue comment](https://docs.github.com/rest/reference/issues#create-an-issue-comment)." We recommend creating a review comment using `line`, `side`, and optionally `start_line` and `start_side` if your comment applies to more than one line in the pull request diff.
  
  The `position` parameter is deprecated. If you use `position`, the `line`, `side`, `start_line`, and `start_side` parameters are not required.
  
  **Note:** The position value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Alternative usage: Pull.Review.Comment.createComment
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-review-comment-for-a-pull-request
  * @param options Request options.
  */
    async createPullRequestReviewComment(options) {
        return this.Pull.Review.Comment.createComment(options);
    }
    /**
  * Creates a reply to a review comment for a pull request. For the `comment_id`, provide the ID of the review comment you are replying to. This must be the ID of a _top-level review comment_, not a reply to that comment. Replies to replies are not supported.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Alternative usage: Pull.Review.Comment.createReply
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-reply-for-a-review-comment
  * @param options Request options.
  */
    async createReplyForPullRequestReviewComment(options) {
        return this.Pull.Review.Comment.createReply(options);
    }
    /**
  * Lists repositories for the specified organization.
  
  **Note:** In order to see the `security_and_analysis` block for a repository you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
  * Alternative usage: Repository.getOrganizationRepositories
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-organization-repositories
  * @param options Request options.
  */
    async getOrganizationRepositories(options) {
        return this.Repository.getOrganizationRepositories(options);
    }
    /**
  * Creates a new repository in the specified organization. The authenticated user must be a member of the organization.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository
  * Alternative usage: Repository.createOrganizationRepository
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-an-organization-repository
  * @param options Request options.
  */
    async createOrganizationRepository(options) {
        return this.Repository.createOrganizationRepository(options);
    }
    /**
  * The `parent` and `source` objects are present when the repository is a fork. `parent` is the repository this repository was forked from, `source` is the ultimate source for the network.
  
  **Note:** In order to see the `security_and_analysis` block for a repository you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
  * Alternative usage: Repository.getRepository
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository
  * @param options Request options.
  */
    async getRepository(options) {
        return this.Repository.getRepository(options);
    }
    /**
     * **Note**: To edit a repository's topics, use the [Replace all repository topics](https://docs.github.com/rest/reference/repos#replace-all-repository-topics) endpoint.
     * Alternative usage: Repository.updateRepository
     * Documentation: https://docs.github.com/en/rest/reference/repos#update-a-repository
     * @param options Request options.
     */
    async updateRepository(options) {
        return this.Repository.updateRepository(options);
    }
    /**
  * Deleting a repository requires admin access. If OAuth is used, the `delete_repo` scope is required.
  
  If an organization owner has configured the organization to prevent members from deleting organization-owned
  repositories, you will get a `403 Forbidden` response.
  * Alternative usage: Repository.deleteRepository
  * Documentation: https://docs.github.com/rest/reference/repos#delete-a-repository
  * @param options Request options.
  */
    async deleteRepository(options) {
        return this.Repository.deleteRepository(options);
    }
    /**
     * Enables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
     * Alternative usage: Repository.enableAutomatedSecurityFixes
     * Documentation: https://docs.github.com/en/rest/reference/repos#enable-automated-security-fixes
     * @param options Request options.
     */
    async enableAutomatedSecurityFixesForRepository(options) {
        return this.Repository.enableAutomatedSecurityFixes(options);
    }
    /**
     * Disables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
     * Alternative usage: Repository.disableAutomatedSecurityFixes
     * Documentation: https://docs.github.com/en/rest/reference/repos#disable-automated-security-fixes
     * @param options Request options.
     */
    async disableAutomatedSecurityFixesForRepository(options) {
        return this.Repository.disableAutomatedSecurityFixes(options);
    }
    /**
  * List any syntax errors that are detected in the CODEOWNERS
  file.
  
  For more information about the correct CODEOWNERS syntax,
  see "[About code owners](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners)."
  * Alternative usage: Repository.getCodeOwnersErrors
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-codeowners-errors
  * @param options Request options.
  */
    async getRepositoryCodeOwnersErrors(options) {
        return this.Repository.getCodeOwnersErrors(options);
    }
    /**
  * Lists contributors to the specified repository and sorts them by the number of commits per contributor in descending order. This endpoint may return information that is a few hours old because the GitHub REST API caches contributor data to improve performance.
  
  GitHub identifies contributors by author email address. This endpoint groups contribution counts by GitHub user, which includes all associated email addresses. To improve performance, only the first 500 author email addresses in the repository link to GitHub users. The rest will appear as anonymous contributors without associated GitHub user information.
  * Alternative usage: Repository.getContributors
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-contributors
  * @param options Request options.
  */
    async getRepositoryContributors(options) {
        return this.Repository.getContributors(options);
    }
    /**
  * You can use this endpoint to trigger a webhook event called `repository_dispatch` when you want activity that happens outside of GitHub to trigger a GitHub Actions workflow or GitHub App webhook. You must configure your GitHub Actions workflow or GitHub App to run when the `repository_dispatch` event occurs. For an example `repository_dispatch` webhook payload, see "[RepositoryDispatchEvent](https://docs.github.com/webhooks/event-payloads/#repository_dispatch)."
  
  The `client_payload` parameter is available for any extra information that your workflow might need. This parameter is a JSON payload that will be passed on when the webhook event is dispatched. For example, the `client_payload` can include a message that a user would like to send using a GitHub Actions workflow. Or the `client_payload` can be used as a test to debug your workflow.
  
  This endpoint requires write access to the repository by providing either:
  
    - Personal access tokens with `repo` scope. For more information, see "[Creating a personal access token for the command line](https://docs.github.com/articles/creating-a-personal-access-token-for-the-command-line)" in the GitHub Help documentation.
    - GitHub Apps with both `metadata:read` and `contents:read&write` permissions.
  
  This input example shows how you can use the `client_payload` as a test to debug your workflow.
  * Alternative usage: Repository.createDispatchEvent
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-dispatch-event
  * @param options Request options.
  */
    async createRepositoryDispatchEvent(options) {
        return this.Repository.createDispatchEvent(options);
    }
    /**
     * Lists languages for the specified repository. The value shown for each language is the number of bytes of code written in that language.
     * Alternative usage: Repository.getLanguages
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-languages
     * @param options Request options.
     */
    async getRepositoryLanguages(options) {
        return this.Repository.getLanguages(options);
    }
    /**
     *
     * Alternative usage: Repository.getTags
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-tags
     * @param options Request options.
     */
    async getRepositoryTags(options) {
        return this.Repository.getTags(options);
    }
    /**
     *
     * Alternative usage: Repository.getTeams
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-teams
     * @param options Request options.
     */
    async getRepositoryTeams(options) {
        return this.Repository.getTeams(options);
    }
    /**
     *
     * Alternative usage: Repository.getTopics
     * Documentation: https://docs.github.com/en/rest/reference/repos#get-all-repository-topics
     * @param options Request options.
     */
    async getRepositoryTopics(options) {
        return this.Repository.getTopics(options);
    }
    /**
     *
     * Alternative usage: Repository.replaceTopics
     * Documentation: https://docs.github.com/en/rest/reference/repos#replace-all-repository-topics
     * @param options Request options.
     */
    async replaceRepositoryTopics(options) {
        return this.Repository.replaceTopics(options);
    }
    /**
     * A transfer request will need to be accepted by the new owner when transferring a personal repository to another user. The response will contain the original `owner`, and the transfer will continue asynchronously. For more details on the requirements to transfer personal and organization-owned repositories, see [about repository transfers](https://docs.github.com/articles/about-repository-transfers/).
     * Alternative usage: Repository.transferRepository
     * Documentation: https://docs.github.com/en/rest/reference/repos#transfer-a-repository
     * @param options Request options.
     */
    async transferRepository(options) {
        return this.Repository.transferRepository(options);
    }
    /**
     * Shows whether dependency alerts are enabled or disabled for a repository. The authenticated user must have admin read access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
     * Alternative usage: Repository.isVulnerabilityAlertsEnabled
     * Documentation: https://docs.github.com/en/rest/reference/repos#check-if-vulnerability-alerts-are-enabled-for-a-repository
     * @param options Request options.
     */
    async isRepositoryVulnerabilityAlertsEnabled(options) {
        return this.Repository.isVulnerabilityAlertsEnabled(options);
    }
    /**
     * Enables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
     * Alternative usage: Repository.enableVulnerabilityAlerts
     * Documentation: https://docs.github.com/en/rest/reference/repos#enable-vulnerability-alerts
     * @param options Request options.
     */
    async enabledRepositoryVulnerabilityAlerts(options) {
        return this.Repository.enableVulnerabilityAlerts(options);
    }
    /**
  * Disables dependency alerts and the dependency graph for a repository.
  The authenticated user must have admin access to the repository. For more information,
  see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
  * Alternative usage: Repository.disableVulnerabilityAlerts
  * Documentation: https://docs.github.com/en/rest/reference/repos#disable-vulnerability-alerts
  * @param options Request options.
  */
    async disableRepositoryVulnerabilityAlerts(options) {
        return this.Repository.disableVulnerabilityAlerts(options);
    }
    /**
  * Creates a new repository using a repository template. Use the `template_owner` and `template_repo` route parameters to specify the repository to use as the template. If the repository is not public, the authenticated user must own or be a member of an organization that owns the repository. To check if a repository is available to use as a template, get the repository's information using the [Get a repository](https://docs.github.com/rest/reference/repos#get-a-repository) endpoint and check that the `is_template` key is `true`.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository
  * Alternative usage: Repository.createRepositoryFromTemplate
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-using-a-template
  * @param options Request options.
  */
    async createRepositoryFromTemplate(options) {
        return this.Repository.createRepositoryFromTemplate(options);
    }
    /**
  * Lists all public repositories in the order that they were created.
  
  Note:
  - For GitHub Enterprise Server, this endpoint will only list repositories available to all users on the enterprise.
  - Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of repositories.
  * Alternative usage: Repository.getPublicRepositories
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-public-repositories
  * @param options Request options.
  */
    async getPublicRepositories(options) {
        return this.Repository.getPublicRepositories(options);
    }
    /**
  * Lists repositories that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access.
  
  The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
  * Alternative usage: Repository.getRepositoriesForAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-repositories-for-the-authenticated-user
  * @param options Request options.
  */
    async getRepositoriesForAuthenticatedUser(options) {
        return this.Repository.getRepositoriesForAuthenticatedUser(options);
    }
    /**
  * Creates a new repository for the authenticated user.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository.
  * Alternative usage: Repository.createRepositoryForAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-for-the-authenticated-user
  * @param options Request options.
  */
    async createRepositoryForAuthenticatedUser(options) {
        return this.Repository.createRepositoryForAuthenticatedUser(options);
    }
    /**
     * Lists public repositories for the specified user. Note: For GitHub AE, this endpoint will list internal repositories for the specified user.
     * Alternative usage: Repository.getRepositoriesForUser
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repositories-for-a-user
     * @param options Request options.
     */
    async getRepositoriesForUser(options) {
        return this.Repository.getRepositoriesForUser(options);
    }
    /**
  * Gets the contents of a file or directory in a repository. Specify the file path or directory in `:path`. If you omit
  `:path`, you will receive the contents of the repository's root directory. See the description below regarding what the API response includes for directories.
  
  Files and symlinks support [a custom media type](https://docs.github.com/rest/reference/repos#custom-media-types) for
  retrieving the raw content or rendered HTML (when supported). All content types support [a custom media
  type](https://docs.github.com/rest/reference/repos#custom-media-types) to ensure the content is returned in a consistent
  object format.
  
  **Note**:
  *   To get a repository's contents recursively, you can [recursively get the tree](https://docs.github.com/rest/reference/git#trees).
  *   This API has an upper limit of 1,000 files for a directory. If you need to retrieve more files, use the [Git Trees
  API](https://docs.github.com/rest/reference/git#get-a-tree).
  *   This API supports files up to 1 megabyte in size.
  
  #### If the content is a directory
  The response will be an array of objects, one object for each item in the directory.
  When listing the contents of a directory, submodules have their "type" specified as "file". Logically, the value
  _should_ be "submodule". This behavior exists in API v3 [for backwards compatibility purposes](https://git.io/v1YCW).
  In the next major version of the API, the type will be returned as "submodule".
  
  #### If the content is a symlink
  If the requested `:path` points to a symlink, and the symlink's target is a normal file in the repository, then the
  API responds with the content of the file (in the format shown in the example. Otherwise, the API responds with an object
  describing the symlink itself.
  
  #### If the content is a submodule
  The `submodule_git_url` identifies the location of the submodule repository, and the `sha` identifies a specific
  commit within the submodule repository. Git uses the given URL when cloning the submodule repository, and checks out
  the submodule at that specific commit.
  
  If the submodule repository is not hosted on github.com, the Git URLs (`git_url` and `_links["git"]`) and the
  github.com URLs (`html_url` and `_links["html"]`) will have null values.
  * Alternative usage: Repository.Content.getContent
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-repository-content
  * @param options Request options.
  */
    async getRepositoryContent(options) {
        return this.Repository.Content.getContent(options);
    }
    /**
  * Creates a new file or replaces an existing file in a repository. You must authenticate using an access token with the `workflow` scope to use this endpoint.
  
  **Note:** If you use this endpoint and the "[Delete a file](https://docs.github.com/rest/reference/repos/#delete-file)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
  * Alternative usage: Repository.Content.createOrUpdateFileContents
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-or-update-file-contents
  * @param options Request options.
  */
    async createOrUpdateFileContents(options) {
        return this.Repository.Content.createOrUpdateFileContents(options);
    }
    /**
  * Deletes a file in a repository.
  
  You can provide an additional `committer` parameter, which is an object containing information about the committer. Or, you can provide an `author` parameter, which is an object containing information about the author.
  
  The `author` section is optional and is filled in with the `committer` information if omitted. If the `committer` information is omitted, the authenticated user's information is used.
  
  You must provide values for both `name` and `email`, whether you choose to use `author` or `committer`. Otherwise, you'll receive a `422` status code.
  
  **Note:** If you use this endpoint and the "[Create or update file contents](https://docs.github.com/rest/reference/repos/#create-or-update-file-contents)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
  * Alternative usage: Repository.Content.deleteFile
  * Documentation: https://docs.github.com/en/rest/reference/repos#delete-a-file
  * @param options Request options.
  */
    async deleteFile(options) {
        return this.Repository.Content.deleteFile(options);
    }
    /**
  * Gets the preferred README for a repository.
  
  READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
  * Alternative usage: Repository.Content.getRepositoryReadme
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository-readme
  * @param options Request options.
  */
    async getRepositoryReadme(options) {
        return this.Repository.Content.getRepositoryReadme(options);
    }
    /**
  * Gets the README from a repository directory.
  
  READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
  * Alternative usage: Repository.Content.getRepositoryReadmeForDirectory
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository-readme-for-a-directory
  * @param options Request options.
  */
    async getRepositoryReadmeForDirectory(options) {
        return this.Repository.Content.getRepositoryReadmeForDirectory(options);
    }
    /**
  * For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
  Organization members with write, maintain, or admin privileges on the organization-owned repository can use this endpoint.
  
  Team members will include the members of child teams.
  
  You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
  endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
  endpoint.
  * Alternative usage: Repository.Collaborator.getCollaborators
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-collaborators
  * @param options Request options.
  */
    async getRepositoryCollaborators(options) {
        return this.Repository.Collaborator.getCollaborators(options);
    }
    /**
  * For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
  
  Team members will include the members of child teams.
  
  You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
  endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
  endpoint.
  * Alternative usage: Repository.Collaborator.isUserCollaborator
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#check-if-a-user-is-a-repository-collaborator
  * @param options Request options.
  */
    async isUserRepositoryCollaborator(options) {
        return this.Repository.Collaborator.isUserCollaborator(options);
    }
    /**
  * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  
  Adding an outside collaborator may be restricted by enterprise administrators. For more information, see "[Enforcing repository management policies in your enterprise](https://docs.github.com/admin/policies/enforcing-policies-for-your-enterprise/enforcing-repository-management-policies-in-your-enterprise#enforcing-a-policy-for-inviting-outside-collaborators-to-repositories)."
  
  For more information on permission levels, see "[Repository permission levels for an organization](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/repository-permission-levels-for-an-organization#permission-levels-for-repositories-owned-by-an-organization)". There are restrictions on which permissions can be granted to organization members when an organization base role is in place. In this case, the permission being given must be equal to or higher than the org base permission. Otherwise, the request will fail with:
  
  ```
  Cannot assign {member} permission of {role name}
  ```
  
  Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
  
  The invitee will receive a notification that they have been invited to the repository, which they must accept or decline. They may do this via the notifications page, the email they receive, or by using the [repository invitations API endpoints](https://docs.github.com/rest/reference/repos#invitations).
  
  **Updating an existing collaborator's permission level**
  
  The endpoint can also be used to change the permissions of an existing collaborator without first removing and re-adding the collaborator. To change the permissions, use the same endpoint and pass a different `permission` parameter. The response will be a `204`, with no other indication that the permission level changed.
  
  **Rate limits**
  
  You are limited to sending 50 invitations to a repository per 24 hour period. Note there is no limit if you are inviting organization members to an organization repository.
  * Alternative usage: Repository.Collaborator.addCollaborator
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#add-a-repository-collaborator
  * @param options Request options.
  */
    async addRepositoryCollaborator(options) {
        return this.Repository.Collaborator.addCollaborator(options);
    }
    /**
     *
     * Alternative usage: Repository.Collaborator.removeCollaborator
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#remove-a-repository-collaborator
     * @param options Request options.
     */
    async removeRepositoryCollaborator(options) {
        return this.Repository.Collaborator.removeCollaborator(options);
    }
    /**
     * Checks the repository permission of a collaborator. The possible repository permissions are `admin`, `write`, `read`, and `none`.
     * Alternative usage: Repository.Collaborator.getPermissionsForUser
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#get-repository-permissions-for-a-user
     * @param options Request options.
     */
    async getRepositoryPermissionsForUser(options) {
        return this.Repository.Collaborator.getPermissionsForUser(options);
    }
    /**
     * When authenticating as a user with admin rights to a repository, this endpoint will list all currently open repository invitations.
     * Alternative usage: Repository.Collaborator.Invitation.getInvitations
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-invitations
     * @param options Request options.
     */
    async getRepositoryInvitations(options) {
        return this.Repository.Collaborator.Invitation.getInvitations(options);
    }
    /**
     *
     * Alternative usage: Repository.Collaborator.Invitation.updateInvitation
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#update-a-repository-invitation
     * @param options Request options.
     */
    async updateRepositoryInvitation(options) {
        return this.Repository.Collaborator.Invitation.updateInvitation(options);
    }
    /**
     *
     * Alternative usage: Repository.Collaborator.Invitation.deleteInvitation
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#delete-a-repository-invitation
     * @param options Request options.
     */
    async deleteInvitation(options) {
        return this.Repository.Collaborator.Invitation.deleteInvitation(options);
    }
    /**
     * When authenticating as a user, this endpoint will list all currently open repository invitations for that user.
     * Alternative usage: Repository.Collaborator.Invitation.getInvitationsForAuthenticatedUser
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-invitations-for-the-authenticated-user
     * @param options Request options.
     */
    async getRepositoryInvitationsForAuthenticatedUser(options) {
        return this.Repository.Collaborator.Invitation.getInvitationsForAuthenticatedUser(options);
    }
    /**
     *
     * Alternative usage: Repository.Collaborator.Invitation.acceptInvitation
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#accept-a-repository-invitation
     * @param options Request options.
     */
    async acceptRepositoryInvitation(options) {
        return this.Repository.Collaborator.Invitation.acceptInvitation(options);
    }
    /**
     *
     * Alternative usage: Repository.Collaborator.Invitation.declineInvitation
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#decline-a-repository-invitation
     * @param options Request options.
     */
    async declineRepositoryInvitation(options) {
        return this.Repository.Collaborator.Invitation.declineInvitation(options);
    }
    /**
     *
     * Alternative usage: Repository.Fork.getForks
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-forks
     * @param options Request options.
     */
    async getRepositoryForks(options) {
        return this.Repository.Fork.getForks(options);
    }
    /**
  * Create a fork for the authenticated user.
  
  **Note**: Forking a Repository happens asynchronously. You may have to wait a short period of time before you can access the git objects. If this takes longer than 5 minutes, be sure to contact [GitHub Support](https://support.github.com/contact?tags=dotcom-rest-api).
  * Alternative usage: Repository.Fork.createFork
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-fork
  * @param options Request options.
  */
    async createRepositoryFork(options) {
        return this.Repository.Fork.createFork(options);
    }
    /**
     * Simple filtering of deployments is available via query parameters:
     * Alternative usage: Deployment.getDeployments
     * Documentation: https://docs.github.com/en/rest/reference/deployments#list-deployments
     * @param options Request options.
     */
    async getDeployments(options) {
        return this.Deployment.getDeployments(options);
    }
    /**
  * Deployments offer a few configurable parameters with certain defaults.
  
  The `ref` parameter can be any named branch, tag, or SHA. At GitHub we often deploy branches and verify them
  before we merge a pull request.
  
  The `environment` parameter allows deployments to be issued to different runtime environments. Teams often have
  multiple environments for verifying their applications, such as `production`, `staging`, and `qa`. This parameter
  makes it easier to track which environments have requested deployments. The default environment is `production`.
  
  The `auto_merge` parameter is used to ensure that the requested ref is not behind the repository's default branch. If
  the ref _is_ behind the default branch for the repository, we will attempt to merge it for you. If the merge succeeds,
  the API will return a successful merge commit. If merge conflicts prevent the merge from succeeding, the API will
  return a failure response.
  
  By default, [commit statuses](https://docs.github.com/rest/commits/statuses) for every submitted context must be in a `success`
  state. The `required_contexts` parameter allows you to specify a subset of contexts that must be `success`, or to
  specify contexts that have not yet been submitted. You are not required to use commit statuses to deploy. If you do
  not require any contexts or create any commit statuses, the deployment will always succeed.
  
  The `payload` parameter is available for any extra information that a deployment system might need. It is a JSON text
  field that will be passed on when a deployment event is dispatched.
  
  The `task` parameter is used by the deployment system to allow different execution paths. In the web world this might
  be `deploy:migrations` to run schema changes on the system. In the compiled world this could be a flag to compile an
  application with debugging enabled.
  
  Users with `repo` or `repo_deployment` scopes can create a deployment for a given ref.
  
  #### Merged branch response
  You will see this response when GitHub automatically merges the base branch into the topic branch instead of creating
  a deployment. This auto-merge happens when:
  *   Auto-merge option is enabled in the repository
  *   Topic branch does not include the latest changes on the base branch, which is `master` in the response example
  *   There are no merge conflicts
  
  If there are no new commits in the base branch, a new request to create a deployment should give a successful
  response.
  
  #### Merge conflict response
  This error happens when the `auto_merge` option is enabled and when the default branch (in this case `master`), can't
  be merged into the branch that's being deployed (in this case `topic-branch`), due to merge conflicts.
  
  #### Failed commit status checks
  This error happens when the `required_contexts` parameter indicates that one or more contexts need to have a `success`
  status for the commit to be deployed, but one or more of the required contexts do not have a state of `success`.
  * Alternative usage: Deployment.createDeployment
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-a-deployment
  * @param options Request options.
  */
    async createDeployment(options) {
        return this.Deployment.createDeployment(options);
    }
    /**
     *
     * Alternative usage: Deployment.getDeployment
     * Documentation: https://docs.github.com/en/rest/reference/deployments#get-a-deployment
     * @param options Request options.
     */
    async getDeployment(options) {
        return this.Deployment.getDeployment(options);
    }
    /**
  * If the repository only has one deployment, you can delete the deployment regardless of its status. If the repository has more than one deployment, you can only delete inactive deployments. This ensures that repositories with multiple deployments will always have an active deployment. Anyone with `repo` or `repo_deployment` scopes can delete a deployment.
  
  To set a deployment as inactive, you must:
  
  *   Create a new deployment that is active so that the system has a record of the current state, then delete the previously active deployment.
  *   Mark the active deployment as inactive by adding any non-successful deployment status.
  
  For more information, see "[Create a deployment](https://docs.github.com/rest/deployments/deployments/#create-a-deployment)" and "[Create a deployment status](https://docs.github.com/rest/deployments/deployment-statuses#create-a-deployment-status)."
  * Alternative usage: Deployment.deleteDeployment
  * Documentation: https://docs.github.com/en/rest/reference/deployments#delete-a-deployment
  * @param options Request options.
  */
    async deleteDeployment(options) {
        return this.Deployment.deleteDeployment(options);
    }
    /**
     * Users with pull access can view deployment statuses for a deployment:
     * Alternative usage: Deployment.Status.getStatuses
     * Documentation: https://docs.github.com/en/rest/reference/deployments#list-deployment-statuses
     * @param options Request options.
     */
    async getDeploymentStatuses(options) {
        return this.Deployment.Status.getStatuses(options);
    }
    /**
  * Users with `push` access can create deployment statuses for a given deployment.
  
  GitHub Apps require `read & write` access to "Deployments" and `read-only` access to "Repo contents" (for private repos). OAuth Apps require the `repo_deployment` scope.
  * Alternative usage: Deployment.Status.createStatus
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-a-deployment-status
  * @param options Request options.
  */
    async createDeploymentStatus(options) {
        return this.Deployment.Status.createStatus(options);
    }
    /**
     * Users with pull access can view a deployment status for a deployment:
     * Alternative usage: Deployment.Status.getStatus
     * Documentation: https://docs.github.com/en/rest/reference/deployments#get-a-deployment-status
     * @param options Request options.
     */
    async getDeploymentStatus(options) {
        return this.Deployment.Status.getStatus(options);
    }
    /**
     *
     * Alternative usage: Deployment.Key.getKeys
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#list-deploy-keys
     * @param options Request options.
     */
    async getDeploymentKeys(options) {
        return this.Deployment.Key.getKeys(options);
    }
    /**
     * You can create a read-only deploy key.
     * Alternative usage: Deployment.Key.createKey
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#create-a-deploy-key
     * @param options Request options.
     */
    async createDeploymentKey(options) {
        return this.Deployment.Key.createKey(options);
    }
    /**
     *
     * Alternative usage: Deployment.Key.getKey
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#get-a-deploy-key
     * @param options Request options.
     */
    async getDeploymentKey(options) {
        return this.Deployment.Key.getKey(options);
    }
    /**
     * Deploy keys are immutable. If you need to update a key, remove the key and create a new one instead.
     * Alternative usage: Deployment.Key.deleteKey
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#delete-a-deploy-key
     * @param options Request options.
     */
    async deleteDeploymentKey(options) {
        return this.Deployment.Key.deleteKey(options);
    }
    /**
  * Get all environments for a repository.
  
  Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
  * Alternative usage: Deployment.Environment.getEnvironments
  * Documentation: https://docs.github.com/en/rest/reference/deployments#get-all-environments
  * @param options Request options.
  */
    async getDeploymentEnvironments(options) {
        return this.Deployment.Environment.getEnvironments(options);
    }
    /**
  * **Note:** To get information about name patterns that branches must match in order to deploy to this environment, see "[Get a deployment branch policy](/rest/deployments/branch-policies#get-a-deployment-branch-policy)."
  
  Anyone with read access to the repository can use this endpoint. If the
  repository is private, you must use an access token with the `repo` scope. GitHub
  Apps must have the `actions:read` permission to use this endpoint.
  * Alternative usage: Deployment.Environment.getEnvironment
  * Documentation: https://docs.github.com/en/rest/reference/deployments#get-an-environment
  * @param options Request options.
  */
    async getDeploymentEnvironment(options) {
        return this.Deployment.Environment.getEnvironment(options);
    }
    /**
  * Create or update an environment with protection rules, such as required reviewers. For more information about environment protection rules, see "[Environments](/actions/reference/environments#environment-protection-rules)."
  
  **Note:** To create or update name patterns that branches must match in order to deploy to this environment, see "[Deployment branch policies](/rest/deployments/branch-policies)."
  
  **Note:** To create or update secrets for an environment, see "[Secrets](/rest/reference/actions#secrets)."
  
  You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration:write` permission for the repository to use this endpoint.
  * Alternative usage: Deployment.Environment.createOrUpdateEnvironment
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-or-update-an-environment
  * @param options Request options.
  */
    async createOrUpdateDeploymentEnvironment(options) {
        return this.Deployment.Environment.createOrUpdateEnvironment(options);
    }
    /**
     * You must authenticate using an access token with the repo scope to use this endpoint.
     * Alternative usage: Deployment.Environment.deleteEnvironment
     * Documentation: https://docs.github.com/en/rest/reference/deployments#delete-an-environment
     * @param options Request options.
     */
    async deleteDeploymentEnvironment(options) {
        return this.Deployment.Environment.deleteEnvironment(options);
    }
    /**
     *
     * Alternative usage: Branch.getBranches
     * Documentation: https://docs.github.com/en/rest/reference/branches#list-branches
     * @param options Request options.
     */
    async getBranches(options) {
        return this.Branch.getBranches(options);
    }
    /**
     *
     * Alternative usage: Branch.getBranch
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-a-branch
     * @param options Request options.
     */
    async getBranch(options) {
        return this.Branch.getBranch(options);
    }
    /**
  * Renames a branch in a repository.
  
  **Note:** Although the API responds immediately, the branch rename process might take some extra time to complete in the background. You won't be able to push to the old branch name while the rename process is in progress. For more information, see "[Renaming a branch](https://docs.github.com/github/administering-a-repository/renaming-a-branch)".
  
  The permissions required to use this endpoint depends on whether you are renaming the default branch.
  
  To rename a non-default branch:
  
  * Users must have push access.
  * GitHub Apps must have the `contents:write` repository permission.
  
  To rename the default branch:
  
  * Users must have admin or owner permissions.
  * GitHub Apps must have the `administration:write` repository permission.
  * Alternative usage: Branch.renameBranch
  * Documentation: https://docs.github.com/en/rest/reference/branches#rename-a-branch
  * @param options Request options.
  */
    async renameBranch(options) {
        return this.Branch.renameBranch(options);
    }
    /**
     * Sync a branch of a forked repository to keep it up-to-date with the upstream repository.
     * Alternative usage: Branch.syncForkBranch
     * Documentation: https://docs.github.com/en/rest/reference/branches#sync-a-fork-branch-with-the-upstream-repository
     * @param options Request options.
     */
    async syncForkBranch(options) {
        return this.Branch.syncForkBranch(options);
    }
    /**
     *
     * Alternative usage: Branch.mergeBranch
     * Documentation: https://docs.github.com/en/rest/reference/branches#merge-a-branch
     * @param options Request options.
     */
    async mergeBranch(options) {
        return this.Branch.mergeBranch(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.getProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-branch-protection
     * @param options Request options.
     */
    async getBranchProtection(options) {
        return this.Branch.Protection.getProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Protecting a branch requires admin or owner permissions to the repository.
  
  **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
  
  **Note**: The list of users, apps, and teams in total is limited to 100 items.
  * Alternative usage: Branch.Protection.updateProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-branch-protection
  * @param options Request options.
  */
    async updateBranchProtection(options) {
        return this.Branch.Protection.updateProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.deleteProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#delete-branch-protection
     * @param options Request options.
     */
    async deleteBranchProtection(options) {
        return this.Branch.Protection.deleteProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Admin.getProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-admin-branch-protection
     * @param options Request options.
     */
    async getAdminBranchProtection(options) {
        return this.Branch.Protection.Admin.getProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Adding admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  * Alternative usage: Branch.Protection.Admin.setProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#set-admin-branch-protection
  * @param options Request options.
  */
    async setAdminBranchProtection(options) {
        return this.Branch.Protection.Admin.setProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Removing admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  * Alternative usage: Branch.Protection.Admin.deleteProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#delete-admin-branch-protection
  * @param options Request options.
  */
    async deleteAdminBranchProtection(options) {
        return this.Branch.Protection.Admin.deleteProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Pull.Review.getProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-pull-request-review-protection
     * @param options Request options.
     */
    async getBranchPullRequestReviewProtection(options) {
        return this.Branch.Protection.Pull.Review.getProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Updating pull request review enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  
  **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
  * Alternative usage: Branch.Protection.Pull.Review.updateProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-pull-request-review-protection
  * @param options Request options.
  */
    async updateBranchPullRequestReviewProtection(options) {
        return this.Branch.Protection.Pull.Review.updateProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to check whether a branch requires signed commits. An enabled status of `true` indicates you must sign commits on this branch. For more information, see [Signing commits with GPG](https://docs.github.com/articles/signing-commits-with-gpg) in GitHub Help.
  
  **Note**: You must enable branch protection to require signed commits.
  * Alternative usage: Branch.Protection.Commit.Signature.getProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#get-commit-signature-protection
  * @param options Request options.
  */
    async getBranchCommitSignatureProtection(options) {
        return this.Branch.Protection.Commit.Signature.getProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to require signed commits on a branch. You must enable branch protection to require signed commits.
  * Alternative usage: Branch.Protection.Commit.Signature.createProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#create-commit-signature-protection
  * @param options Request options.
  */
    async createBranchCommitSignatureProtection(options) {
        return this.Branch.Protection.Commit.Signature.createProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to disable required signed commits on a branch. You must enable branch protection to require signed commits.
  * Alternative usage: Branch.Protection.Commit.Signature.deleteProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#delete-commit-signature-protection
  * @param options Request options.
  */
    async deleteBranchCommitSignatureProtection(options) {
        return this.Branch.Protection.Commit.Signature.deleteProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.getProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-status-checks-protection
     * @param options Request options.
     */
    async getBranchStatusCheckProtection(options) {
        return this.Branch.Protection.Status.Check.getProtection(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Updating required status checks requires admin or owner permissions to the repository and branch protection to be enabled.
  * Alternative usage: Branch.Protection.Status.Check.updateProtection
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-status-check-protection
  * @param options Request options.
  */
    async updateBranchStatusCheckProtection(options) {
        return this.Branch.Protection.Status.Check.updateProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.removeProtection
     * Documentation: https://docs.github.com/en/rest/reference/branches#remove-status-check-protection
     * @param options Request options.
     */
    async removeBranchStatusCheckProtection(options) {
        return this.Branch.Protection.Status.Check.removeProtection(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.getContexts
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-all-status-check-contexts
     * @param options Request options.
     */
    async getBranchStatusCheckContexts(options) {
        return this.Branch.Protection.Status.Check.getContexts(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.addContexts
     * Documentation: https://docs.github.com/en/rest/reference/branches#add-status-check-contexts
     * @param options Request options.
     */
    async addBranchStatusCheckContexts(options) {
        return this.Branch.Protection.Status.Check.addContexts(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.setContexts
     * Documentation: https://docs.github.com/en/rest/reference/branches#set-status-check-contexts
     * @param options Request options.
     */
    async setBranchStatusCheckContexts(options) {
        return this.Branch.Protection.Status.Check.setContexts(options);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Alternative usage: Branch.Protection.Status.Check.removeContexts
     * Documentation: https://docs.github.com/en/rest/reference/branches#remove-status-check-contexts
     * @param options Request options.
     */
    async removeBranchStatusCheckContexts(options) {
        return this.Branch.Protection.Status.Check.removeContexts(options);
    }
    /**
  * Returns an array of references from your Git database that match the supplied name. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't exist in the repository, but existing refs start with `:ref`, they will be returned as an array.
  
  When you use this endpoint without providing a `:ref`, it will return an array of all the references from your Git database, including notes and stashes if they exist on the server. Anything in the namespace is returned, not just `heads` and `tags`.
  
  **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  
  If you request matching references for a branch named `feature` but the branch `feature` doesn't exist, the response can still include other matching head refs that start with the word `feature`, such as `featureA` and `featureB`.
  * Alternative usage: Git.Reference.getMatchingReferences
  * Documentation: https://docs.github.com/en/rest/reference/git#list-matching-references
  * @param options Request options.
  */
    async getGitMatchingReferences(options) {
        return this.Git.Reference.getMatchingReferences(options);
    }
    /**
  * Returns a single reference from your Git database. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't match an existing ref, a `404` is returned.
  
  **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  * Alternative usage: Git.Reference.getReference
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-reference
  * @param options Request options.
  */
    async getGitReference(options) {
        return this.Git.Reference.getReference(options);
    }
    /**
     * Creates a reference for your repository. You are unable to create new references for empty repositories, even if the commit SHA-1 hash used exists. Empty repositories are repositories without branches.
     * Alternative usage: Git.Reference.createReference
     * Documentation: https://docs.github.com/en/rest/reference/git#create-a-reference
     * @param options Request options.
     */
    async createGitReference(options) {
        return this.Git.Reference.createReference(options);
    }
    /**
     *
     * Alternative usage: Git.Reference.updateReference
     * Documentation: https://docs.github.com/en/rest/reference/git#update-a-reference
     * @param options Request options.
     */
    async updateGitReference(options) {
        return this.Git.Reference.updateReference(options);
    }
    /**
     *
     * Alternative usage: Git.Reference.deleteReference
     * Documentation: https://docs.github.com/en/rest/reference/git#delete-a-reference
     * @param options Request options.
     */
    async deleteGitReference(options) {
        return this.Git.Reference.deleteReference(options);
    }
    /**
     *
     * Alternative usage: Git.Blob.createBlob
     * Documentation: https://docs.github.com/en/rest/reference/git#create-a-blob
     * @param options Request options.
     */
    async createGitBlob(options) {
        return this.Git.Blob.createBlob(options);
    }
    /**
  * The `content` in the response will always be Base64 encoded.
  
  _Note_: This API supports blobs up to 100 megabytes in size.
  * Alternative usage: Git.Blob.getBlob
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-blob
  * @param options Request options.
  */
    async getGitBlob(options) {
        return this.Git.Blob.getBlob(options);
    }
    /**
  * Note that creating a tag object does not create the reference that makes a tag in Git. If you want to create an annotated tag in Git, you have to do this call to create the tag object, and then [create](https://docs.github.com/rest/reference/git#create-a-reference) the `refs/tags/[tag]` reference. If you want to create a lightweight tag, you only have to [create](https://docs.github.com/rest/reference/git#create-a-reference) the tag reference - this call would be unnecessary.
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Git.Tag.createTag
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-tag-object
  * @param options Request options.
  */
    async createGitTag(options) {
        return this.Git.Tag.createTag(options);
    }
    /**
  * **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Git.Tag.getTag
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-tag
  * @param options Request options.
  */
    async getGitTag(options) {
        return this.Git.Tag.getTag(options);
    }
    /**
  * The tree creation API accepts nested entries. If you specify both a tree and a nested path modifying that tree, this endpoint will overwrite the contents of the tree with the new path contents, and create a new tree structure.
  
  If you use this endpoint to add, delete, or modify the file contents in a tree, you will need to commit the tree and then update a branch to point to the commit. For more information see "[Create a commit](https://docs.github.com/rest/reference/git#create-a-commit)" and "[Update a reference](https://docs.github.com/rest/reference/git#update-a-reference)."
  
  Returns an error if you try to delete a file that does not exist.
  * Alternative usage: Git.Tree.createTree
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-tree
  * @param options Request options.
  */
    async createGitTree(options) {
        return this.Git.Tree.createTree(options);
    }
    /**
  * Returns a single tree using the SHA1 value for that tree.
  
  If `truncated` is `true` in the response then the number of items in the `tree` array exceeded our maximum limit. If you need to fetch more items, use the non-recursive method of fetching trees, and fetch one sub-tree at a time.
  * Alternative usage: Git.Tree.getTree
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-tree
  * @param options Request options.
  */
    async getGitTree(options) {
        return this.Git.Tree.getTree(options);
    }
    /**
  * Creates a new Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Git.Commit.createCommit
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-commit
  * @param options Request options.
  */
    async createGitCommit(options) {
        return this.Git.Commit.createCommit(options);
    }
    /**
  * Gets a Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Git.Commit.getCommit
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-commit
  * @param options Request options.
  */
    async getGitCommit(options) {
        return this.Git.Commit.getCommit(options);
    }
    /**
  * **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Commit.getCommits
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commits
  * @param options Request options.
  */
    async getCommits(options) {
        return this.Commit.getCommits(options);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Returns all branches where the given commit SHA is the HEAD, or latest commit for the branch.
  * Alternative usage: Commit.getBranchesForHead
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-branches-for-head-commit
  * @param options Request options.
  */
    async getBranchesForHeadCommit(options) {
        return this.Commit.getBranchesForHead(options);
    }
    /**
     * Lists the merged pull request that introduced the commit to the repository. If the commit is not present in the default branch, additionally returns open pull requests associated with the commit. The results may include open and closed pull requests. Additional preview headers may be required to see certain details for associated pull requests, such as whether a pull request is in a draft state. For more information about previews that might affect this endpoint, see the [List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests) endpoint.
     * Alternative usage: Commit.getPullRequestsForCommit
     * Documentation: https://docs.github.com/en/rest/reference/commits#list-pull-requests-associated-with-a-commit
     * @param options Request options.
     */
    async getPullRequestsForCommit(options) {
        return this.Commit.getPullRequestsForCommit(options);
    }
    /**
  * Returns the contents of a single commit reference. You must have `read` access for the repository to use this endpoint.
  
  **Note:** If there are more than 300 files in the commit diff, the response will include pagination link headers for the remaining files, up to a limit of 3000 files. Each page contains the static commit information, and the only changes are to the file listing.
  
  You can pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to  fetch `diff` and `patch` formats. Diffs with binary data will have no `patch` property.
  
  To return only the SHA-1 hash of the commit reference, you can provide the `sha` custom [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) in the `Accept` header. You can use this endpoint to check if a remote reference's SHA-1 hash is the same as your local reference's SHA-1 hash by providing the local SHA-1 reference as the ETag.
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Commit.getCommit
  * Documentation: https://docs.github.com/en/rest/reference/commits#get-a-commit
  * @param options Request options.
  */
    async getCommit(options) {
        return this.Commit.getCommit(options);
    }
    /**
  * Compares two commits against one another. You can compare branches in the same repository, or you can compare branches that exist in different repositories within the same repository network, including fork branches. For more information about how to view a repository's network, see "[Understanding connections between repositories](https://docs.github.com/repositories/viewing-activity-and-data-for-your-repository/understanding-connections-between-repositories)."
  
  This endpoint is equivalent to running the `git log BASE..HEAD` command, but it returns commits in a different order. The `git log BASE..HEAD` command returns commits in reverse chronological order, whereas the API returns commits in chronological order. You can pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
  
  The API response includes details about the files that were changed between the two commits. This includes the status of the change (if a file was added, removed, modified, or renamed), and details of the change itself. For example, files with a `renamed` status have a `previous_filename` field showing the previous filename of the file, and files with a `modified` status have a `patch` field showing the changes made to the file.
  
  When calling this endpoint without any paging parameter (`per_page` or `page`), the returned list is limited to 250 commits, and the last commit in the list is the most recent of the entire comparison.
  
  **Working with large comparisons**
  
  To process a response with a large number of commits, use a query parameter (`per_page` or `page`) to paginate the results. When using pagination:
  
  - The list of changed files is only shown on the first page of results, but it includes all changed files for the entire comparison.
  - The results are returned in chronological order, but the last commit in the returned list may not be the most recent one in the entire set if there are more pages of results.
  
  For more information on working with pagination, see "[Using pagination in the REST API](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api)."
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The `verification` object includes the following fields:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Alternative usage: Commit.compareCommits
  * Documentation: https://docs.github.com/en/rest/reference/commits#compare-two-commits
  * @param options Request options.
  */
    async compareCommits(options) {
        return this.Commit.compareCommits(options);
    }
    /**
  * Commit Comments use [these custom media types](https://docs.github.com/rest/reference/repos#custom-media-types). You can read more about the use of media types in the API [here](https://docs.github.com/rest/overview/media-types/).
  
  Comments are ordered by ascending ID.
  * Alternative usage: Commit.Comment.getCommentsForRepository
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-comments-for-a-repository
  * @param options Request options.
  */
    async getCommitCommentsForRepository(options) {
        return this.Commit.Comment.getCommentsForRepository(options);
    }
    /**
     *
     * Alternative usage: Commit.Comment.getComment
     * Documentation: https://docs.github.com/en/rest/reference/commits#get-a-commit-comment
     * @param options Request options.
     */
    async getCommitComment(options) {
        return this.Commit.Comment.getComment(options);
    }
    /**
     *
     * Alternative usage: Commit.Comment.updateComment
     * Documentation: https://docs.github.com/en/rest/reference/commits#update-a-commit-comment
     * @param options Request options.
     */
    async updateCommitComment(options) {
        return this.Commit.Comment.updateComment(options);
    }
    /**
     *
     * Alternative usage: Commit.Comment.deleteComment
     * Documentation: https://docs.github.com/en/rest/reference/commits#delete-a-commit-comment
     * @param options Request options.
     */
    async deleteCommitComment(options) {
        return this.Commit.Comment.deleteComment(options);
    }
    /**
     * Use the `:commit_sha` to specify the commit that will have its comments listed.
     * Alternative usage: Commit.Comment.getComments
     * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-comments
     * @param options Request options.
     */
    async getCommitComments(options) {
        return this.Commit.Comment.getComments(options);
    }
    /**
  * Create a comment for a commit using its `:commit_sha`.
  
  This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Alternative usage: Commit.Comment.createComment
  * Documentation: https://docs.github.com/en/rest/reference/commits#create-a-commit-comment
  * @param options Request options.
  */
    async createCommitComment(options) {
        return this.Commit.Comment.createComment(options);
    }
    /**
  * Users with pull access in a repository can access a combined view of commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name.
  
  
  Additionally, a combined `state` is returned. The `state` is one of:
  
  *   **failure** if any of the contexts report as `error` or `failure`
  *   **pending** if there are no statuses or a context is `pending`
  *   **success** if the latest status for all contexts is `success`
  * Alternative usage: Commit.Status.getCombinedStatusForReference
  * Documentation: https://docs.github.com/en/rest/reference/commits#get-the-combined-status-for-a-specific-reference
  * @param options Request options.
  */
    async getCombinedCommitStatusForReference(options) {
        return this.Commit.Status.getCombinedStatusForReference(options);
    }
    /**
  * Users with pull access in a repository can view commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name. Statuses are returned in reverse chronological order. The first status in the list will be the latest one.
  
  This resource is also available via a legacy route: `GET /repos/:owner/:repo/statuses/:ref`.
  * Alternative usage: Commit.Status.getStatusesForReference
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-statuses-for-a-reference
  * @param options Request options.
  */
    async getCommitStatusesForReference(options) {
        return this.Commit.Status.getStatusesForReference(options);
    }
    /**
  * Users with push access in a repository can create commit statuses for a given SHA.
  
  Note: there is a limit of 1000 statuses per `sha` and `context` within a repository. Attempts to create more than 1000 statuses will result in a validation error.
  * Alternative usage: Commit.Status.createStatus
  * Documentation: https://docs.github.com/en/rest/reference/commits#create-a-commit-status
  * @param options Request options.
  */
    async createCommitStatus(options) {
        return this.Commit.Status.createStatus(options);
    }
    /**
  * List issues across owned and member repositories assigned to the authenticated user.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Alternative usage: Issue.getIssuesForAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user
  * @param options Request options.
  */
    async getIssuesForAuthenticatedUser(options) {
        return this.Issue.getIssuesForAuthenticatedUser(options);
    }
    /**
  * List issues in an organization assigned to the authenticated user.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Alternative usage: Issue.getOrganizationIssuesForAuthenticatedUser
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user
  * @param options Request options.
  */
    async getOrganizationIssuesForAuthenticatedUser(options) {
        return this.Issue.getOrganizationIssuesForAuthenticatedUser(options);
    }
    /**
  * List issues in a repository. Only open issues will be listed.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Alternative usage: Issue.getRepositoryIssues
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-repository-issues
  * @param options Request options.
  */
    async getRepositoryIssues(options) {
        return this.Issue.getRepositoryIssues(options);
    }
    /**
  * Any user with pull access to a repository can create an issue. If [issues are disabled in the repository](https://docs.github.com/articles/disabling-issues/), the API returns a `410 Gone` status.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Alternative usage: Issue.createIssue
  * Documentation: https://docs.github.com/en/rest/reference/issues#create-an-issue
  * @param options Request options.
  */
    async createIssue(options) {
        return this.Issue.createIssue(options);
    }
    /**
  * The API returns a [`301 Moved Permanently` status](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-redirects-redirects) if the issue was
  [transferred](https://docs.github.com/articles/transferring-an-issue-to-another-repository/) to another repository. If
  the issue was transferred to or deleted from a repository where the authenticated user lacks read access, the API
  returns a `404 Not Found` status. If the issue was deleted from a repository where the authenticated user has read
  access, the API returns a `410 Gone` status. To receive webhook events for transferred and deleted issues, subscribe
  to the [`issues`](https://docs.github.com/webhooks/event-payloads/#issues) webhook.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Alternative usage: Issue.getIssue
  * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue
  * @param options Request options.
  */
    async getIssue(options) {
        return this.Issue.getIssue(options);
    }
    /**
     * Issue owners and users with push access can edit an issue.
     * Alternative usage: Issue.updateIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-an-issue
     * @param options Request options.
     */
    async updateIssue(options) {
        return this.Issue.updateIssue(options);
    }
    /**
  * Users with push access can lock an issue or pull request's conversation.
  
  Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
  * Alternative usage: Issue.lockIssue
  * Documentation: https://docs.github.com/en/rest/reference/issues#lock-an-issue
  * @param options Request options.
  */
    async lockIssue(options) {
        return this.Issue.lockIssue(options);
    }
    /**
     * Users with push access can unlock an issue's conversation.
     * Alternative usage: Issue.unlockIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#unlock-an-issue
     * @param options Request options.
     */
    async unlockIssue(options) {
        return this.Issue.unlockIssue(options);
    }
    /**
  * You can use the REST API to list comments on issues and pull requests for a repository. Every pull request is an issue, but not every issue is a pull request.
  
  By default, issue comments are ordered by ascending ID.
  * Alternative usage: Issue.Comment.getCommentsForRepository
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-comments-for-a-repository
  * @param options Request options.
  */
    async getIssueCommentsForRepository(options) {
        return this.Issue.Comment.getCommentsForRepository(options);
    }
    /**
     * You can use the REST API to get comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Alternative usage: Issue.Comment.getComment
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue-comment
     * @param options Request options.
     */
    async getIssueComment(options) {
        return this.Issue.Comment.getComment(options);
    }
    /**
     * You can use the REST API to update comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Alternative usage: Issue.Comment.updateComment
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-an-issue-comment
     * @param options Request options.
     */
    async updateIssueComment(options) {
        return this.Issue.Comment.updateComment(options);
    }
    /**
     * You can use the REST API to delete comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Alternative usage: Issue.Comment.deleteComment
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-an-issue-comment
     * @param options Request options.
     */
    async deleteIssueComment(options) {
        return this.Issue.Comment.deleteComment(options);
    }
    /**
  * You can use the REST API to list comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
  
  Issue comments are ordered by ascending ID.
  * Alternative usage: Issue.Comment.getComments
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-comments
  * @param options Request options.
  */
    async getIssueComments(options) {
        return this.Issue.Comment.getComments(options);
    }
    /**
  *
  You can use the REST API to create comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications).
  Creating content too quickly using this endpoint may result in secondary rate limiting.
  See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)"
  and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)"
  for details.
  * Alternative usage: Issue.Comment.createComment
  * Documentation: https://docs.github.com/en/rest/reference/issues#create-an-issue-comment
  * @param options Request options.
  */
    async createIssueComment(options) {
        return this.Issue.Comment.createComment(options);
    }
    /**
     *
     * Alternative usage: Issue.Milestone.getMilestones
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-milestones
     * @param options Request options.
     */
    async getIssueMilestones(options) {
        return this.Issue.Milestone.getMilestones(options);
    }
    /**
     *
     * Alternative usage: Issue.Milestone.createMilestone
     * Documentation: https://docs.github.com/en/rest/reference/issues#create-a-milestone
     * @param options Request options.
     */
    async createIssueMilestone(options) {
        return this.Issue.Milestone.createMilestone(options);
    }
    /**
     *
     * Alternative usage: Issue.Milestone.getMilestone
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-a-milestone
     * @param options Request options.
     */
    async getIssueMilestone(options) {
        return this.Issue.Milestone.getMilestone(options);
    }
    /**
     *
     * Alternative usage: Issue.Milestone.updateMilestone
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-a-milestone
     * @param options Request options.
     */
    async updateIssueMilestone(options) {
        return this.Issue.Milestone.updateMilestone(options);
    }
    /**
     *
     * Alternative usage: Issue.Milestone.deleteMilestone
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-a-milestone
     * @param options Request options.
     */
    async deleteIssueMilestone(options) {
        return this.Issue.Milestone.deleteMilestone(options);
    }
    /**
     * Lists the [available assignees](https://docs.github.com/articles/assigning-issues-and-pull-requests-to-other-github-users/) for issues in a repository.
     * Alternative usage: Issue.Assignee.getAssignees
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-assignees
     * @param options Request options.
     */
    async getIssueAssignees(options) {
        return this.Issue.Assignee.getAssignees(options);
    }
    /**
  * Checks if a user has permission to be assigned to an issue in this repository.
  
  If the `assignee` can be assigned to issues in the repository, a `204` header with no content is returned.
  
  Otherwise a `404` status code is returned.
  * Alternative usage: Issue.Assignee.canUserBeAssigned
  * Documentation: https://docs.github.com/en/rest/reference/issues#check-if-a-user-can-be-assigned
  * @param options Request options.
  */
    async canUserBeAssigneToIssue(options) {
        return this.Issue.Assignee.canUserBeAssigned(options);
    }
    /**
     * Adds up to 10 assignees to an issue. Users already assigned to an issue are not replaced.
     * Alternative usage: Issue.Assignee.addAssignees
     * Documentation: https://docs.github.com/en/rest/reference/issues#add-assignees-to-an-issue
     * @param options Request options.
     */
    async addIssueAssignees(options) {
        return this.Issue.Assignee.addAssignees(options);
    }
    /**
     * Removes one or more assignees from an issue.
     * Alternative usage: Issue.Assignee.removeAssignees
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-assignees-from-an-issue
     * @param options Request options.
     */
    async removeIssueAssignees(options) {
        return this.Issue.Assignee.removeAssignees(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.getLabels
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-an-issue
     * @param options Request options.
     */
    async getIssueLabels(options) {
        return this.Issue.Label.getLabels(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.addLabelsToIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#add-labels-to-an-issue
     * @param options Request options.
     */
    async addLabelsToIssue(options) {
        return this.Issue.Label.addLabelsToIssue(options);
    }
    /**
     * Removes any previous labels and sets the new labels for an issue.
     * Alternative usage: Issue.Label.setLabelsToIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#set-labels-for-an-issue
     * @param options Request options.
     */
    async setLabelsToIssue(options) {
        return this.Issue.Label.setLabelsToIssue(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.removeLabelsFromIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-all-labels-from-an-issue
     * @param options Request options.
     */
    async removeLabelsFromIssue(options) {
        return this.Issue.Label.removeLabelsFromIssue(options);
    }
    /**
     * Removes the specified label from the issue, and returns the remaining labels on the issue. This endpoint returns a `404 Not Found` status if the label does not exist.
     * Alternative usage: Issue.Label.removeLabelFromIssue
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-a-label-from-an-issue
     * @param options Request options.
     */
    async removeLabelFromIssue(options) {
        return this.Issue.Label.removeLabelFromIssue(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.getLabelsForRepository
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-a-repository
     * @param options Request options.
     */
    async getIssueLabelsForRepository(options) {
        return this.Issue.Label.getLabelsForRepository(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.createLabel
     * Documentation: https://docs.github.com/en/rest/reference/issues#create-a-label
     * @param options Request options.
     */
    async createIssueLabel(options) {
        return this.Issue.Label.createLabel(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.getLabel
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-a-label
     * @param options Request options.
     */
    async getIssueLabel(options) {
        return this.Issue.Label.getLabel(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.updateLabel
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-a-label
     * @param options Request options.
     */
    async updateIssueLabel(options) {
        return this.Issue.Label.updateLabel(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.deleteLabel
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-a-label
     * @param options Request options.
     */
    async deleteIssueLabel(options) {
        return this.Issue.Label.deleteLabel(options);
    }
    /**
     *
     * Alternative usage: Issue.Label.getLabelsForIssuesInMilestone
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-issues-in-a-milestone
     * @param options Request options.
     */
    async getLabelsForIssuesInMilestone(options) {
        return this.Issue.Label.getLabelsForIssuesInMilestone(options);
    }
    /**
     *
     * Alternative usage: Issue.Event.getEventsForRepository
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-events-for-a-repository
     * @param options Request options.
     */
    async getIssueEventsForRepository(options) {
        return this.Issue.Event.getEventsForRepository(options);
    }
    /**
     *
     * Alternative usage: Issue.Event.getEvent
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue-event
     * @param options Request options.
     */
    async getIssueEvent(options) {
        return this.Issue.Event.getEvent(options);
    }
    /**
     *
     * Alternative usage: Issue.Event.getEvents
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-events
     * @param options Request options.
     */
    async getIssueEvents(options) {
        return this.Issue.Event.getEvents(options);
    }
    /**
     * Lists the projects in an organization. Returns a `404 Not Found` status if projects are disabled in the organization. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.getOrganizationProjects
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-organization-projects
     * @param options Request options.
     */
    async getOrganizationProjects(options) {
        return this.Project.getOrganizationProjects(options);
    }
    /**
     * Creates an organization project board. Returns a `410 Gone` status if projects are disabled in the organization or if the organization does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.createOrganizationProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-an-organization-project
     * @param options Request options.
     */
    async createOrganizationProject(options) {
        return this.Project.createOrganizationProject(options);
    }
    /**
     * Gets a project by its `id`. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.getProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#get-a-project
     * @param options Request options.
     */
    async getProject(options) {
        return this.Project.getProject(options);
    }
    /**
     * Updates a project board's information. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.updateProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#update-a-project
     * @param options Request options.
     */
    async updateProject(options) {
        return this.Project.updateProject(options);
    }
    /**
     * Deletes a project board. Returns a `404 Not Found` status if projects are disabled.
     * Alternative usage: Project.deleteProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#delete-a-project
     * @param options Request options.
     */
    async deleteProject(options) {
        return this.Project.deleteProject(options);
    }
    /**
     * Lists the projects in a repository. Returns a `404 Not Found` status if projects are disabled in the repository. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.getRepositoryProjects
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-repository-projects
     * @param options Request options.
     */
    async getRepositoryProjects(options) {
        return this.Project.getRepositoryProjects(options);
    }
    /**
     * Creates a repository project board. Returns a `410 Gone` status if projects are disabled in the repository or if the repository does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.createRepositoryProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-a-repository-project
     * @param options Request options.
     */
    async createRepositoryProject(options) {
        return this.Project.createRepositoryProject(options);
    }
    /**
     *
     * Alternative usage: Project.getUserProjects
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-user-projects
     * @param options Request options.
     */
    async getUserProjects(options) {
        return this.Project.getUserProjects(options);
    }
    /**
     * Creates a user project board. Returns a `410 Gone` status if the user does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Alternative usage: Project.createUserProject
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-a-user-project
     * @param options Request options.
     */
    async createUserProject(options) {
        return this.Project.createUserProject(options);
    }
    /**
  * Searches for query terms inside of a file. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for code, you can get text match metadata for the file **content** and file **path** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find the definition of the `addClass` function inside [jQuery](https://github.com/jquery/jquery) repository, your query would look something like this:
  
  `q=addClass+in:file+language:js+repo:jquery/jquery`
  
  This query searches for the keyword `addClass` within a file's contents. The query limits the search to files where the language is JavaScript in the `jquery/jquery` repository.
  
  #### Considerations for code search
  
  Due to the complexity of searching code, there are a few restrictions on how searches are performed:
  
  *   Only the _default branch_ is considered. In most cases, this will be the `master` branch.
  *   Only files smaller than 384 KB are searchable.
  *   You must always include at least one search term when searching source code. For example, searching for [`language:go`](https://github.com/search?utf8=%E2%9C%93&q=language%3Ago&type=Code) is not valid, while [`amazing
  language:go`](https://github.com/search?utf8=%E2%9C%93&q=amazing+language%3Ago&type=Code) is.
  
  **Note:** Starting on April 10, 2023, code search on GitHub.com will have a separate
  rate limit from other search types, of 10 requests per minute, and all code
  search requests will require authentication. For more information, see [this blog post](https://github.blog/changelog/2023-03-10-changes-to-the-code-search-api/).
  * Alternative usage: Search.searchCode
  * Documentation: https://docs.github.com/en/rest/reference/search#search-code
  * @param options Request options.
  */
    async searchCode(options) {
        return this.Search.searchCode(options);
    }
    /**
  * Find commits via various criteria on the default branch (usually `main`). This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for commits, you can get text match metadata for the **message** field when you provide the `text-match` media type. For more details about how to receive highlighted search results, see [Text match
  metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find commits related to CSS in the [octocat/Spoon-Knife](https://github.com/octocat/Spoon-Knife) repository. Your query would look something like this:
  
  `q=repo:octocat/Spoon-Knife+css`
  * Alternative usage: Search.searchCommits
  * Documentation: https://docs.github.com/en/rest/reference/search#search-commits
  * @param options Request options.
  */
    async searchCommits(options) {
        return this.Search.searchCommits(options);
    }
    /**
  * Find issues by state and keyword. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for issues, you can get text match metadata for the issue **title**, issue **body**, and issue **comment body** fields when you pass the `text-match` media type. For more details about how to receive highlighted
  search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find the oldest unresolved Python bugs on Windows. Your query might look something like this.
  
  `q=windows+label:bug+language:python+state:open&sort=created&order=asc`
  
  This query searches for the keyword `windows`, within any open issue that is labeled as `bug`. The search runs across repositories whose primary language is Python. The results are sorted by creation date in ascending order, which means the oldest issues appear first in the search results.
  
  **Note:** For [user-to-server](https://docs.github.com/developers/apps/identifying-and-authorizing-users-for-github-apps#user-to-server-requests) GitHub App requests, you can't retrieve a combination of issues and pull requests in a single query. Requests that don't include the `is:issue` or `is:pull-request` qualifier will receive an HTTP `422 Unprocessable Entity` response. To get results for both issues and pull requests, you must send separate queries for issues and pull requests. For more information about the `is` qualifier, see "[Searching only issues or pull requests](https://docs.github.com/github/searching-for-information-on-github/searching-issues-and-pull-requests#search-only-issues-or-pull-requests)."
  * Alternative usage: Search.searchIssuesAndPullRequests
  * Documentation: https://docs.github.com/en/rest/reference/search#search-issues-and-pull-requests
  * @param options Request options.
  */
    async searchIssuesAndPullRequests(options) {
        return this.Search.searchIssuesAndPullRequests(options);
    }
    /**
  * Find labels in a repository with names or descriptions that match search keywords. Returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for labels, you can get text match metadata for the label **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find labels in the `linguist` repository that match `bug`, `defect`, or `enhancement`. Your query might look like this:
  
  `q=bug+defect+enhancement&repository_id=64778136`
  
  The labels that best match the query appear first in the search results.
  * Alternative usage: Search.searchLabels
  * Documentation: https://docs.github.com/en/rest/reference/search#search-labels
  * @param options Request options.
  */
    async searchLabels(options) {
        return this.Search.searchLabels(options);
    }
    /**
  * Find repositories via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for repositories, you can get text match metadata for the **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to search for popular Tetris repositories written in assembly code, your query might look like this:
  
  `q=tetris+language:assembly&sort=stars&order=desc`
  
  This query searches for repositories with the word `tetris` in the name, the description, or the README. The results are limited to repositories where the primary language is assembly. The results are sorted by stars in descending order, so that the most popular repositories appear first in the search results.
  * Alternative usage: Search.searchRepositories
  * Documentation: https://docs.github.com/en/rest/reference/search#search-repositories
  * @param options Request options.
  */
    async searchRepositories(options) {
        return this.Search.searchRepositories(options);
    }
    /**
  * Find topics via various criteria. Results are sorted by best match. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination). See "[Searching topics](https://docs.github.com/articles/searching-topics/)" for a detailed list of qualifiers.
  
  When searching for topics, you can get text match metadata for the topic's **short\_description**, **description**, **name**, or **display\_name** field when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to search for topics related to Ruby that are featured on https://github.com/topics. Your query might look like this:
  
  `q=ruby+is:featured`
  
  This query searches for topics with the keyword `ruby` and limits the results to find only topics that are featured. The topics that are the best match for the query appear first in the search results.
  * Alternative usage: Search.searchTopics
  * Documentation: https://docs.github.com/en/rest/reference/search#search-topics
  * @param options Request options.
  */
    async searchTopics(options) {
        return this.Search.searchTopics(options);
    }
    /**
  * Find users via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for users, you can get text match metadata for the issue **login**, public **email**, and **name** fields when you pass the `text-match` media type. For more details about highlighting search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata). For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you're looking for a list of popular users, you might try this query:
  
  `q=tom+repos:%3E42+followers:%3E1000`
  
  This query searches for users with the name `tom`. The results are restricted to users with more than 42 repositories and over 1,000 followers.
  * Alternative usage: Search.searchUsers
  * Documentation: https://docs.github.com/en/rest/reference/search#search-users
  * @param options Request options.
  */
    async searchUsers(options) {
        return this.Search.searchUsers(options);
    }
}
class OrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Member = new OrganizationMemberGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Lists all organizations, in the order that they were created on GitHub.
  
  **Note:** Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of organizations.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations
  * @param options Request options.
  */
    async getOrganizations(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/organizations`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * To see many of the organization response values, you need to be an authenticated organization owner with the `admin:org` scope. When the value of `two_factor_requirement_enabled` is `true`, the organization requires all members, billing managers, and outside collaborators to enable [two-factor authentication](https://docs.github.com/articles/securing-your-account-with-two-factor-authentication-2fa/).
  
  GitHub Apps with the `Organization plan` permission can use this endpoint to retrieve information about an organization's GitHub plan. See "[Authenticating with GitHub Apps](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/)" for details. For an example response, see 'Response with GitHub plan information' below."
  * Documentation: https://docs.github.com/en/rest/reference/orgs#get-an-organization
  * @param options Request options.
  */
    async getOrganization(options) {
        const { headers, errorStrategy, org } = options;
        const request = new Request("GET", `/orgs/${encodeURIComponent(org)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * **Parameter Deprecation Notice:** GitHub will replace and discontinue `members_allowed_repository_creation_type` in favor of more granular permissions. The new input parameters are `members_can_create_public_repositories`, `members_can_create_private_repositories` for all organizations and `members_can_create_internal_repositories` for organizations associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+. For more information, see the [blog post](https://developer.github.com/changes/2019-12-03-internal-visibility-changes).
  
  Enables an authenticated organization owner with the `admin:org` scope to update the organization's profile and member privileges.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#update-an-organization
  * @param options Request options.
  */
    async updateOrganization(options) {
        const { body, headers, errorStrategy, org } = options;
        const request = new Request("PATCH", `/orgs/${encodeURIComponent(org)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists all GitHub Apps in an organization. The installation count includes all GitHub Apps installed on repositories in the organization. You must be an organization owner with `admin:read` scope to use this endpoint.
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-app-installations-for-an-organization
     * @param options Request options.
     */
    async getInstallations(options) {
        const { headers, errorStrategy, org, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/orgs/${encodeURIComponent(org)}/installations`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * List organizations for the authenticated user.
  
  **OAuth scope requirements**
  
  This only lists organizations that your authorization allows you to operate on in some way (e.g., you can list teams with `read:org` scope, you can publicize your organization membership with `user` scope, etc.). Therefore, this API requires at least `user` or `read:org` scope. OAuth requests with insufficient scope receive a `403 Forbidden` response.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations-for-the-authenticated-user
  * @param options Request options.
  */
    async getOrganizationsForAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/orgs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * List [public organization memberships](https://docs.github.com/articles/publicizing-or-concealing-organization-membership) for the specified user.
  
  This method only lists _public_ memberships, regardless of authentication. If you need to fetch all of the organization memberships (public and private) for the authenticated user, use the [List organizations for the authenticated user](https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user) API instead.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organizations-for-a-user
  * @param options Request options.
  */
    async getOrganizationsForUser(options) {
        const { headers, errorStrategy, username, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/users/${encodeURIComponent(username)}/orgs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationMemberGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List all users who are members of an organization. If the authenticated user is also a member of this organization then both concealed and public members will be returned.
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organization-members
     * @param options Request options.
     */
    async getMembers(options) {
        const { headers, errorStrategy, org, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/orgs/${encodeURIComponent(org)}/members`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Check if a user is, publicly or privately, a member of the organization.
     * Documentation: https://docs.github.com/en/rest/reference/orgs#check-organization-membership-for-a-user
     * @param options Request options.
     */
    async checkMembershipForUser(options) {
        const { headers, errorStrategy, org, username } = options;
        const request = new Request("GET", `/orgs/${encodeURIComponent(org)}/members/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Removing a user from this list will remove them from all teams and they will no longer have any access to the organization's repositories.
     * Documentation: https://docs.github.com/en/rest/reference/orgs#remove-an-organization-member
     * @param options Request options.
     */
    async removeMember(options) {
        const { headers, errorStrategy, org, username } = options;
        const request = new Request("DELETE", `/orgs/${encodeURIComponent(org)}/members/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * In order to get a user's membership with an organization, the authenticated user must be an organization member. The `state` parameter in the response can be used to identify the user's membership status.
     * Documentation: https://docs.github.com/en/rest/reference/orgs#get-organization-membership-for-a-user
     * @param options Request options.
     */
    async getMembershipForUser(options) {
        const { headers, errorStrategy, org, username } = options;
        const request = new Request("GET", `/orgs/${encodeURIComponent(org)}/memberships/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Only authenticated organization owners can add a member to the organization or update the member's role.
  
  *   If the authenticated user is _adding_ a member to the organization, the invited user will receive an email inviting them to the organization. The user's [membership status](https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user) will be `pending` until they accept the invitation.
      
  *   Authenticated users can _update_ a user's membership by passing the `role` parameter. If the authenticated user changes a member's role to `admin`, the affected user will receive an email notifying them that they've been made an organization owner. If the authenticated user changes an owner's role to `member`, no email will be sent.
  
  **Rate limits**
  
  To prevent abuse, the authenticated user is limited to 50 organization invitations per 24 hour period. If the organization is more than one month old or on a paid plan, the limit is 500 invitations per 24 hour period.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#set-organization-membership-for-a-user
  * @param options Request options.
  */
    async setMembershipForUser(options) {
        const { body, headers, errorStrategy, org, username } = options;
        const request = new Request("PUT", `/orgs/${encodeURIComponent(org)}/memberships/${encodeURIComponent(username)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * In order to remove a user's membership with an organization, the authenticated user must be an organization owner.
  
  If the specified user is an active member of the organization, this will remove them from the organization. If the specified user has been invited to the organization, this will cancel their invitation. The specified user will receive an email notification in both cases.
  * Documentation: https://docs.github.com/en/rest/reference/orgs#remove-organization-membership-for-a-user
  * @param options Request options.
  */
    async removeMembershipForUser(options) {
        const { headers, errorStrategy, org, username } = options;
        const request = new Request("DELETE", `/orgs/${encodeURIComponent(org)}/memberships/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user
     * @param options Request options.
     */
    async getMembershipsForAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/memberships/orgs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/orgs#get-an-organization-membership-for-the-authenticated-user
     * @param options Request options.
     */
    async getMembershipForAuthenticatedUser(options) {
        const { headers, errorStrategy, org } = options;
        const request = new Request("GET", `/user/memberships/orgs/${encodeURIComponent(org)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/orgs#update-an-organization-membership-for-the-authenticated-user
     * @param options Request options.
     */
    async updateMembershipForAuthenticatedUser(options) {
        const { body, headers, errorStrategy, org } = options;
        const request = new Request("PATCH", `/user/memberships/orgs/${encodeURIComponent(org)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ReleaseGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This returns a list of releases, which does not include regular Git tags that have not been associated with a release. To get a list of Git tags, use the [Repository Tags API](https://docs.github.com/rest/reference/repos#list-repository-tags).
  
  Information about published releases are available to everyone. Only users with push access will receive listings for draft releases.
  * Documentation: https://docs.github.com/en/rest/reference/releases#list-releases
  * @param options Request options.
  */
    async getReleases(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Users with push access to the repository can create a release.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/releases#create-a-release
  * @param options Request options.
  */
    async createRelease(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Generate a name and body describing a [release](https://docs.github.com/rest/reference/repos#releases). The body content will be markdown formatted and contain information like the changes since last release and users who contributed. The generated release notes are not saved anywhere. They are intended to be generated and used when creating a new release.
     * Documentation: https://docs.github.com/en/rest/reference/releases#generate-release-notes-content-for-a-release
     * @param options Request options.
     */
    async generateReleaseNotes(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/generate-notes`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * View the latest published full release for the repository.
  
  The latest release is the most recent non-prerelease, non-draft release, sorted by the `created_at` attribute. The `created_at` attribute is the date of the commit used for the release, and not the date when the release was drafted or published.
  * Documentation: https://docs.github.com/en/rest/reference/releases#get-the-latest-release
  * @param options Request options.
  */
    async getLatestRelease(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/latest`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a published release with the specified tag.
     * Documentation: https://docs.github.com/en/rest/reference/releases#get-a-release-by-tag-name
     * @param options Request options.
     */
    async getReleaseByTagName(options) {
        const { headers, errorStrategy, owner, repo, tag } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/tags/${encodeURIComponent(tag)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * **Note:** This returns an `upload_url` key corresponding to the endpoint for uploading release assets. This key is a [hypermedia resource](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia).
     * Documentation: https://docs.github.com/en/rest/reference/releases#get-a-release
     * @param options Request options.
     */
    async getRelease(options) {
        const { headers, errorStrategy, owner, repo, release_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/${encodeURIComponent(release_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Users with push access to the repository can edit a release.
     * Documentation: https://docs.github.com/en/rest/reference/releases#update-a-release
     * @param options Request options.
     */
    async updateRelease(options) {
        const { body, headers, errorStrategy, owner, repo, release_id } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/${encodeURIComponent(release_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Users with push access to the repository can delete a release.
     * Documentation: https://docs.github.com/en/rest/reference/releases#delete-a-release
     * @param options Request options.
     */
    async deleteRelease(options) {
        const { headers, errorStrategy, owner, repo, release_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/releases/${encodeURIComponent(release_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Block = new UserBlockGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * If the authenticated user is authenticated through basic authentication or OAuth with the `user` scope, then the response lists public and private profile information.
  
  If the authenticated user is authenticated through OAuth without the `user` scope, then the response lists only public profile information.
  * Documentation: https://docs.github.com/en/rest/reference/users#get-the-authenticated-user
  * @param options Request options.
  */
    async getAuthenticatedUser(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/user`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * **Note:** If your email is set to private and you send an `email` parameter as part of this request to update your profile, your privacy settings are still enforced: the email address will not be displayed on your public profile or via the API.
     * Documentation: https://docs.github.com/en/rest/reference/users#update-the-authenticated-user
     * @param options Request options.
     */
    async updateAuthenticatedUser(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PATCH", `/user`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Lists all users, in the order that they signed up on GitHub. This list includes personal user accounts and organization accounts.
  
  Note: Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of users.
  * Documentation: https://docs.github.com/en/rest/reference/users#list-users
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Provides publicly available information about someone with a GitHub account.
  
  GitHub Apps with the `Plan` user permission can use this endpoint to retrieve information about a user's GitHub plan. The GitHub App must be authenticated as a user. See "[Identifying and authorizing users for GitHub Apps](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/)" for details about authentication. For an example response, see 'Response with GitHub plan information' below"
  
  The `email` key in the following response is the publicly visible email address from your GitHub [profile page](https://github.com/settings/profile). When setting up your profile, you can select a primary email address to be “public” which provides an email entry for this endpoint. If you do not set a public email address for `email`, then it will have a value of `null`. You only see publicly visible email addresses when authenticated with GitHub. For more information, see [Authentication](https://docs.github.com/rest/overview/resources-in-the-rest-api#authentication).
  
  The Emails API enables you to list all of your email addresses, and toggle a primary email to be visible publicly. For more information, see "[Emails API](https://docs.github.com/rest/reference/users#emails)".
  * Documentation: https://docs.github.com/en/rest/reference/users#get-a-user
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, username } = options;
        const request = new Request("GET", `/users/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Provides hovercard information when authenticated through basic auth or OAuth with the `repo` scope. You can find out more about someone in relation to their pull requests, issues, repositories, and organizations.
  
  The `subject_type` and `subject_id` parameters provide context for the person's hovercard, which returns more information than without the parameters. For example, if you wanted to find out more about `octocat` who owns the `Spoon-Knife` repository via cURL, it would look like this:
  
  ```shell
   curl -u username:token
    https://api.github.com/users/octocat/hovercard?subject_type=repository&subject_id=1300192
  ```
  * Documentation: https://docs.github.com/en/rest/reference/users#get-contextual-information-for-a-user
  * @param options Request options.
  */
    async getUserContext(options) {
        const { headers, errorStrategy, username, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/users/${encodeURIComponent(username)}/hovercard`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserBlockGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List the users you've blocked on your personal account.
     * Documentation: https://docs.github.com/en/rest/reference/users#list-users-blocked-by-the-authenticated-user
     * @param options Request options.
     */
    async getBlockedUsersByAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/blocks`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/users#check-if-a-user-is-blocked-by-the-authenticated-user
     * @param options Request options.
     */
    async checkIfUserIsBlockedByAuthenticatedUser(options) {
        const { headers, errorStrategy, username } = options;
        const request = new Request("GET", `/user/blocks/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/users#block-a-user
     * @param options Request options.
     */
    async blockUser(options) {
        const { headers, errorStrategy, username } = options;
        const request = new Request("PUT", `/user/blocks/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/users#unblock-a-user
     * @param options Request options.
     */
    async unblockUser(options) {
        const { headers, errorStrategy, username } = options;
        const request = new Request("DELETE", `/user/blocks/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class PullGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Review = new PullReviewGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-pull-requests
     * @param options Request options.
     */
    async getPullRequests(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-pull-request
  * @param options Request options.
  */
    async createPullRequest(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Lists details of a pull request by providing its number.
  
  When you get, [create](https://docs.github.com/rest/reference/pulls/#create-a-pull-request), or [edit](https://docs.github.com/rest/reference/pulls#update-a-pull-request) a pull request, GitHub creates a merge commit to test whether the pull request can be automatically merged into the base branch. This test commit is not added to the base branch or the head branch. You can review the status of the test commit using the `mergeable` key. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  
  The value of the `mergeable` attribute can be `true`, `false`, or `null`. If the value is `null`, then GitHub has started a background job to compute the mergeability. After giving the job time to complete, resubmit the request. When the job finishes, you will see a non-`null` value for the `mergeable` attribute in the response. If `mergeable` is `true`, then `merge_commit_sha` will be the SHA of the _test_ merge commit.
  
  The value of the `merge_commit_sha` attribute changes depending on the state of the pull request. Before merging a pull request, the `merge_commit_sha` attribute holds the SHA of the _test_ merge commit. After merging a pull request, the `merge_commit_sha` attribute changes depending on how you merged the pull request:
  
  *   If merged as a [merge commit](https://docs.github.com/articles/about-merge-methods-on-github/), `merge_commit_sha` represents the SHA of the merge commit.
  *   If merged via a [squash](https://docs.github.com/articles/about-merge-methods-on-github/#squashing-your-merge-commits), `merge_commit_sha` represents the SHA of the squashed commit on the base branch.
  *   If [rebased](https://docs.github.com/articles/about-merge-methods-on-github/#rebasing-and-merging-your-commits), `merge_commit_sha` represents the commit that the base branch was updated to.
  
  Pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-pull-request
  * @param options Request options.
  */
    async getPullRequest(options) {
        const { headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-pull-request
  * @param options Request options.
  */
    async updatePullRequest(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists a maximum of 250 commits for a pull request. To receive a complete commit list for pull requests with more than 250 commits, use the [List commits](https://docs.github.com/rest/reference/repos#list-commits) endpoint.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-commits-on-a-pull-request
     * @param options Request options.
     */
    async getCommits(options) {
        const { headers, errorStrategy, owner, repo, pull_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/commits`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * **Note:** Responses include a maximum of 3000 files. The paginated response returns 30 files per page by default.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-pull-requests-files
     * @param options Request options.
     */
    async getFiles(options) {
        const { headers, errorStrategy, owner, repo, pull_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/files`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/pulls#check-if-a-pull-request-has-been-merged
     * @param options Request options.
     */
    async isMerged(options) {
        const { headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/merge`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#merge-a-pull-request
     * @param options Request options.
     */
    async mergePullRequest(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/merge`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates the pull request branch with the latest upstream changes by merging HEAD from the base branch into the pull request branch.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-pull-request-branch
     * @param options Request options.
     */
    async updatePullRequestBranch(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/update-branch`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PullReviewGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Request = new PullReviewRequestGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new PullReviewCommentGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * The list of reviews returns in chronological order.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#reviews
     * @param options Request options.
     */
    async getReviews(options) {
        const { headers, errorStrategy, owner, repo, pull_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  
  Pull request reviews created in the `PENDING` state are not submitted and therefore do not include the `submitted_at` property in the response. To create a pending review for a pull request, leave the `event` parameter blank. For more information about submitting a `PENDING` review, see "[Submit a review for a pull request](https://docs.github.com/rest/pulls#submit-a-review-for-a-pull-request)."
  
  **Note:** To comment on a specific line in a file, you need to first determine the _position_ of that line in the diff. The GitHub REST API offers the `application/vnd.github.v3.diff` [media type](https://docs.github.com/rest/overview/media-types#commits-commit-comparison-and-pull-requests). To see a pull request diff, add this media type to the `Accept` header of a call to the [single pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) endpoint.
  
  The `position` value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-review-for-a-pull-request
  * @param options Request options.
  */
    async createReview(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-review-for-a-pull-request
     * @param options Request options.
     */
    async getReview(options) {
        const { headers, errorStrategy, owner, repo, pull_number, review_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update the review summary comment with new text.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-review-for-a-pull-request
     * @param options Request options.
     */
    async updateReview(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number, review_id } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/pulls#delete-a-pending-review-for-a-pull-request
     * @param options Request options.
     */
    async deletePendingReview(options) {
        const { headers, errorStrategy, owner, repo, pull_number, review_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * List comments for a specific pull request review.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-comments-for-a-pull-request-review
     * @param options Request options.
     */
    async getComments(options) {
        const { headers, errorStrategy, owner, repo, pull_number, review_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * **Note:** To dismiss a pull request review on a [protected branch](https://docs.github.com/rest/reference/repos#branches), you must be a repository administrator or be included in the list of people or teams who can dismiss pull request reviews.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#dismiss-a-review-for-a-pull-request
     * @param options Request options.
     */
    async dismissReview(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number, review_id } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}/dismissals`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Submits a pending review for a pull request. For more information about creating a pending review for a pull request, see "[Create a review for a pull request](https://docs.github.com/rest/pulls#create-a-review-for-a-pull-request)."
     * Documentation: https://docs.github.com/en/rest/reference/pulls#submit-a-review-for-a-pull-request
     * @param options Request options.
     */
    async submitReview(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number, review_id } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/reviews/${encodeURIComponent(review_id)}/events`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PullReviewRequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Gets the users or teams whose review is requested for a pull request. Once a requested reviewer submits a review, they are no longer considered a requested reviewer. Their review will instead be returned by the [List reviews for a pull request](https://docs.github.com/rest/pulls/reviews#list-reviews-for-a-pull-request) operation.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-requested-reviewers-for-a-pull-request
     * @param options Request options.
     */
    async getReviewers(options) {
        const { headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/requested_reviewers`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#request-reviewers-for-a-pull-request
     * @param options Request options.
     */
    async requestReviewers(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/requested_reviewers`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/pulls#remove-requested-reviewers-from-a-pull-request
     * @param options Request options.
     */
    async removeReviewers(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/requested_reviewers`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PullReviewCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Lists review comments for all pull requests in a repository. By default, review comments are in ascending order by ID.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-review-comments-in-a-repository
     * @param options Request options.
     */
    async getCommentsInRepository(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Provides details for a review comment.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#get-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async getComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Enables you to edit a review comment.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#update-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async updateComment(options) {
        const { body, headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/comments/${encodeURIComponent(comment_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a review comment.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#delete-a-review-comment-for-a-pull-request
     * @param options Request options.
     */
    async deleteComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Lists all review comments for a pull request. By default, review comments are in ascending order by ID.
     * Documentation: https://docs.github.com/en/rest/reference/pulls#list-review-comments-on-a-pull-request
     * @param options Request options.
     */
    async getComments(options) {
        const { headers, errorStrategy, owner, repo, pull_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  *
  Creates a review comment in the pull request diff. To add a regular comment to a pull request timeline, see "[Create an issue comment](https://docs.github.com/rest/reference/issues#create-an-issue-comment)." We recommend creating a review comment using `line`, `side`, and optionally `start_line` and `start_side` if your comment applies to more than one line in the pull request diff.
  
  The `position` parameter is deprecated. If you use `position`, the `line`, `side`, `start_line`, and `start_side` parameters are not required.
  
  **Note:** The position value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-review-comment-for-a-pull-request
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a reply to a review comment for a pull request. For the `comment_id`, provide the ID of the review comment you are replying to. This must be the ID of a _top-level review comment_, not a reply to that comment. Replies to replies are not supported.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/pulls#create-a-reply-for-a-review-comment
  * @param options Request options.
  */
    async createReply(options) {
        const { body, headers, errorStrategy, owner, repo, pull_number, comment_id } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/pulls/${encodeURIComponent(pull_number)}/comments/${encodeURIComponent(comment_id)}/replies`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Content = new RepositoryContentGroup(implementation, this.getGlobalErrorStrategy);
        this.Collaborator = new RepositoryCollaboratorGroup(implementation, this.getGlobalErrorStrategy);
        this.Fork = new RepositoryForkGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Lists repositories for the specified organization.
  
  **Note:** In order to see the `security_and_analysis` block for a repository you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-organization-repositories
  * @param options Request options.
  */
    async getOrganizationRepositories(options) {
        const { headers, errorStrategy, org, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/orgs/${encodeURIComponent(org)}/repos`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new repository in the specified organization. The authenticated user must be a member of the organization.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-an-organization-repository
  * @param options Request options.
  */
    async createOrganizationRepository(options) {
        const { body, headers, errorStrategy, org } = options;
        const request = new Request("POST", `/orgs/${encodeURIComponent(org)}/repos`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * The `parent` and `source` objects are present when the repository is a fork. `parent` is the repository this repository was forked from, `source` is the ultimate source for the network.
  
  **Note:** In order to see the `security_and_analysis` block for a repository you must have admin permissions for the repository or be an owner or security manager for the organization that owns the repository. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository
  * @param options Request options.
  */
    async getRepository(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * **Note**: To edit a repository's topics, use the [Replace all repository topics](https://docs.github.com/rest/reference/repos#replace-all-repository-topics) endpoint.
     * Documentation: https://docs.github.com/en/rest/reference/repos#update-a-repository
     * @param options Request options.
     */
    async updateRepository(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deleting a repository requires admin access. If OAuth is used, the `delete_repo` scope is required.
  
  If an organization owner has configured the organization to prevent members from deleting organization-owned
  repositories, you will get a `403 Forbidden` response.
  * Documentation: https://docs.github.com/rest/reference/repos#delete-a-repository
  * @param options Request options.
  */
    async deleteRepository(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Enables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
     * Documentation: https://docs.github.com/en/rest/reference/repos#enable-automated-security-fixes
     * @param options Request options.
     */
    async enableAutomatedSecurityFixes(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/automated-security-fixes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Disables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
     * Documentation: https://docs.github.com/en/rest/reference/repos#disable-automated-security-fixes
     * @param options Request options.
     */
    async disableAutomatedSecurityFixes(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/automated-security-fixes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * List any syntax errors that are detected in the CODEOWNERS
  file.
  
  For more information about the correct CODEOWNERS syntax,
  see "[About code owners](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners)."
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-codeowners-errors
  * @param options Request options.
  */
    async getCodeOwnersErrors(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/codeowners/errors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Lists contributors to the specified repository and sorts them by the number of commits per contributor in descending order. This endpoint may return information that is a few hours old because the GitHub REST API caches contributor data to improve performance.
  
  GitHub identifies contributors by author email address. This endpoint groups contribution counts by GitHub user, which includes all associated email addresses. To improve performance, only the first 500 author email addresses in the repository link to GitHub users. The rest will appear as anonymous contributors without associated GitHub user information.
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-contributors
  * @param options Request options.
  */
    async getContributors(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/contributors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * You can use this endpoint to trigger a webhook event called `repository_dispatch` when you want activity that happens outside of GitHub to trigger a GitHub Actions workflow or GitHub App webhook. You must configure your GitHub Actions workflow or GitHub App to run when the `repository_dispatch` event occurs. For an example `repository_dispatch` webhook payload, see "[RepositoryDispatchEvent](https://docs.github.com/webhooks/event-payloads/#repository_dispatch)."
  
  The `client_payload` parameter is available for any extra information that your workflow might need. This parameter is a JSON payload that will be passed on when the webhook event is dispatched. For example, the `client_payload` can include a message that a user would like to send using a GitHub Actions workflow. Or the `client_payload` can be used as a test to debug your workflow.
  
  This endpoint requires write access to the repository by providing either:
  
    - Personal access tokens with `repo` scope. For more information, see "[Creating a personal access token for the command line](https://docs.github.com/articles/creating-a-personal-access-token-for-the-command-line)" in the GitHub Help documentation.
    - GitHub Apps with both `metadata:read` and `contents:read&write` permissions.
  
  This input example shows how you can use the `client_payload` as a test to debug your workflow.
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-dispatch-event
  * @param options Request options.
  */
    async createDispatchEvent(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/dispatches`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Lists languages for the specified repository. The value shown for each language is the number of bytes of code written in that language.
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-languages
     * @param options Request options.
     */
    async getLanguages(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/languages`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-tags
     * @param options Request options.
     */
    async getTags(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/tags`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repository-teams
     * @param options Request options.
     */
    async getTeams(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/teams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/repos#get-all-repository-topics
     * @param options Request options.
     */
    async getTopics(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/topics`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/repos#replace-all-repository-topics
     * @param options Request options.
     */
    async replaceTopics(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/topics`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * A transfer request will need to be accepted by the new owner when transferring a personal repository to another user. The response will contain the original `owner`, and the transfer will continue asynchronously. For more details on the requirements to transfer personal and organization-owned repositories, see [about repository transfers](https://docs.github.com/articles/about-repository-transfers/).
     * Documentation: https://docs.github.com/en/rest/reference/repos#transfer-a-repository
     * @param options Request options.
     */
    async transferRepository(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/transfer`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Shows whether dependency alerts are enabled or disabled for a repository. The authenticated user must have admin read access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
     * Documentation: https://docs.github.com/en/rest/reference/repos#check-if-vulnerability-alerts-are-enabled-for-a-repository
     * @param options Request options.
     */
    async isVulnerabilityAlertsEnabled(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/vulnerability-alerts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Enables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
     * Documentation: https://docs.github.com/en/rest/reference/repos#enable-vulnerability-alerts
     * @param options Request options.
     */
    async enableVulnerabilityAlerts(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/vulnerability-alerts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Disables dependency alerts and the dependency graph for a repository.
  The authenticated user must have admin access to the repository. For more information,
  see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
  * Documentation: https://docs.github.com/en/rest/reference/repos#disable-vulnerability-alerts
  * @param options Request options.
  */
    async disableVulnerabilityAlerts(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/vulnerability-alerts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Creates a new repository using a repository template. Use the `template_owner` and `template_repo` route parameters to specify the repository to use as the template. If the repository is not public, the authenticated user must own or be a member of an organization that owns the repository. To check if a repository is available to use as a template, get the repository's information using the [Get a repository](https://docs.github.com/rest/reference/repos#get-a-repository) endpoint and check that the `is_template` key is `true`.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-using-a-template
  * @param options Request options.
  */
    async createRepositoryFromTemplate(options) {
        const { body, headers, errorStrategy, template_owner, template_repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(template_owner)}/${encodeURIComponent(template_repo)}/generate`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Lists all public repositories in the order that they were created.
  
  Note:
  - For GitHub Enterprise Server, this endpoint will only list repositories available to all users on the enterprise.
  - Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of repositories.
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-public-repositories
  * @param options Request options.
  */
    async getPublicRepositories(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/repositories`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Lists repositories that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access.
  
  The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
  * Documentation: https://docs.github.com/en/rest/reference/repos#list-repositories-for-the-authenticated-user
  * @param options Request options.
  */
    async getRepositoriesForAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/repos`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new repository for the authenticated user.
  
  **OAuth scope requirements**
  
  When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
  
  *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
  *   `repo` scope to create a private repository.
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-repository-for-the-authenticated-user
  * @param options Request options.
  */
    async createRepositoryForAuthenticatedUser(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/user/repos`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists public repositories for the specified user. Note: For GitHub AE, this endpoint will list internal repositories for the specified user.
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-repositories-for-a-user
     * @param options Request options.
     */
    async getRepositoriesForUser(options) {
        const { headers, errorStrategy, username, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/users/${encodeURIComponent(username)}/repos`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryContentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Gets the contents of a file or directory in a repository. Specify the file path or directory in `:path`. If you omit
  `:path`, you will receive the contents of the repository's root directory. See the description below regarding what the API response includes for directories.
  
  Files and symlinks support [a custom media type](https://docs.github.com/rest/reference/repos#custom-media-types) for
  retrieving the raw content or rendered HTML (when supported). All content types support [a custom media
  type](https://docs.github.com/rest/reference/repos#custom-media-types) to ensure the content is returned in a consistent
  object format.
  
  **Note**:
  *   To get a repository's contents recursively, you can [recursively get the tree](https://docs.github.com/rest/reference/git#trees).
  *   This API has an upper limit of 1,000 files for a directory. If you need to retrieve more files, use the [Git Trees
  API](https://docs.github.com/rest/reference/git#get-a-tree).
  *   This API supports files up to 1 megabyte in size.
  
  #### If the content is a directory
  The response will be an array of objects, one object for each item in the directory.
  When listing the contents of a directory, submodules have their "type" specified as "file". Logically, the value
  _should_ be "submodule". This behavior exists in API v3 [for backwards compatibility purposes](https://git.io/v1YCW).
  In the next major version of the API, the type will be returned as "submodule".
  
  #### If the content is a symlink
  If the requested `:path` points to a symlink, and the symlink's target is a normal file in the repository, then the
  API responds with the content of the file (in the format shown in the example. Otherwise, the API responds with an object
  describing the symlink itself.
  
  #### If the content is a submodule
  The `submodule_git_url` identifies the location of the submodule repository, and the `sha` identifies a specific
  commit within the submodule repository. Git uses the given URL when cloning the submodule repository, and checks out
  the submodule at that specific commit.
  
  If the submodule repository is not hosted on github.com, the Git URLs (`git_url` and `_links["git"]`) and the
  github.com URLs (`html_url` and `_links["html"]`) will have null values.
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-repository-content
  * @param options Request options.
  */
    async getContent(options) {
        const { headers, errorStrategy, owner, repo, path, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/contents/${encodeURIComponent(path)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new file or replaces an existing file in a repository. You must authenticate using an access token with the `workflow` scope to use this endpoint.
  
  **Note:** If you use this endpoint and the "[Delete a file](https://docs.github.com/rest/reference/repos/#delete-file)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-or-update-file-contents
  * @param options Request options.
  */
    async createOrUpdateFileContents(options) {
        const { body, headers, errorStrategy, owner, repo, path } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/contents/${encodeURIComponent(path)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a file in a repository.
  
  You can provide an additional `committer` parameter, which is an object containing information about the committer. Or, you can provide an `author` parameter, which is an object containing information about the author.
  
  The `author` section is optional and is filled in with the `committer` information if omitted. If the `committer` information is omitted, the authenticated user's information is used.
  
  You must provide values for both `name` and `email`, whether you choose to use `author` or `committer`. Otherwise, you'll receive a `422` status code.
  
  **Note:** If you use this endpoint and the "[Create or update file contents](https://docs.github.com/rest/reference/repos/#create-or-update-file-contents)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
  * Documentation: https://docs.github.com/en/rest/reference/repos#delete-a-file
  * @param options Request options.
  */
    async deleteFile(options) {
        const { body, headers, errorStrategy, owner, repo, path } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/contents/${encodeURIComponent(path)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets the preferred README for a repository.
  
  READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository-readme
  * @param options Request options.
  */
    async getRepositoryReadme(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/readme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets the README from a repository directory.
  
  READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
  * Documentation: https://docs.github.com/en/rest/reference/repos#get-a-repository-readme-for-a-directory
  * @param options Request options.
  */
    async getRepositoryReadmeForDirectory(options) {
        const { headers, errorStrategy, owner, repo, dir, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/readme/${encodeURIComponent(dir)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryCollaboratorGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Invitation = new RepositoryCollaboratorInvitationGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
  Organization members with write, maintain, or admin privileges on the organization-owned repository can use this endpoint.
  
  Team members will include the members of child teams.
  
  You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
  endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
  endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-collaborators
  * @param options Request options.
  */
    async getCollaborators(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/collaborators`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
  
  Team members will include the members of child teams.
  
  You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
  endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
  endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#check-if-a-user-is-a-repository-collaborator
  * @param options Request options.
  */
    async isUserCollaborator(options) {
        const { headers, errorStrategy, owner, repo, username } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/collaborators/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  
  Adding an outside collaborator may be restricted by enterprise administrators. For more information, see "[Enforcing repository management policies in your enterprise](https://docs.github.com/admin/policies/enforcing-policies-for-your-enterprise/enforcing-repository-management-policies-in-your-enterprise#enforcing-a-policy-for-inviting-outside-collaborators-to-repositories)."
  
  For more information on permission levels, see "[Repository permission levels for an organization](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/repository-permission-levels-for-an-organization#permission-levels-for-repositories-owned-by-an-organization)". There are restrictions on which permissions can be granted to organization members when an organization base role is in place. In this case, the permission being given must be equal to or higher than the org base permission. Otherwise, the request will fail with:
  
  ```
  Cannot assign {member} permission of {role name}
  ```
  
  Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
  
  The invitee will receive a notification that they have been invited to the repository, which they must accept or decline. They may do this via the notifications page, the email they receive, or by using the [repository invitations API endpoints](https://docs.github.com/rest/reference/repos#invitations).
  
  **Updating an existing collaborator's permission level**
  
  The endpoint can also be used to change the permissions of an existing collaborator without first removing and re-adding the collaborator. To change the permissions, use the same endpoint and pass a different `permission` parameter. The response will be a `204`, with no other indication that the permission level changed.
  
  **Rate limits**
  
  You are limited to sending 50 invitations to a repository per 24 hour period. Note there is no limit if you are inviting organization members to an organization repository.
  * Documentation: https://docs.github.com/en/rest/reference/collaborators#add-a-repository-collaborator
  * @param options Request options.
  */
    async addCollaborator(options) {
        const { body, headers, errorStrategy, owner, repo, username } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/collaborators/${encodeURIComponent(username)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#remove-a-repository-collaborator
     * @param options Request options.
     */
    async removeCollaborator(options) {
        const { headers, errorStrategy, owner, repo, username } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/collaborators/${encodeURIComponent(username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Checks the repository permission of a collaborator. The possible repository permissions are `admin`, `write`, `read`, and `none`.
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#get-repository-permissions-for-a-user
     * @param options Request options.
     */
    async getPermissionsForUser(options) {
        const { headers, errorStrategy, owner, repo, username } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/collaborators/${encodeURIComponent(username)}/permission`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryCollaboratorInvitationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * When authenticating as a user with admin rights to a repository, this endpoint will list all currently open repository invitations.
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-invitations
     * @param options Request options.
     */
    async getInvitations(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/invitations`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#update-a-repository-invitation
     * @param options Request options.
     */
    async updateInvitation(options) {
        const { body, headers, errorStrategy, owner, repo, invitation_id } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/invitations/${encodeURIComponent(invitation_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#delete-a-repository-invitation
     * @param options Request options.
     */
    async deleteInvitation(options) {
        const { headers, errorStrategy, owner, repo, invitation_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/invitations/${encodeURIComponent(invitation_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * When authenticating as a user, this endpoint will list all currently open repository invitations for that user.
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#list-repository-invitations-for-the-authenticated-user
     * @param options Request options.
     */
    async getInvitationsForAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/repository_invitations`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#accept-a-repository-invitation
     * @param options Request options.
     */
    async acceptInvitation(options) {
        const { headers, errorStrategy, invitation_id } = options;
        const request = new Request("PATCH", `/user/repository_invitations/${encodeURIComponent(invitation_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/collaborators#decline-a-repository-invitation
     * @param options Request options.
     */
    async declineInvitation(options) {
        const { headers, errorStrategy, invitation_id } = options;
        const request = new Request("DELETE", `/user/repository_invitations/${encodeURIComponent(invitation_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryForkGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/repos#list-forks
     * @param options Request options.
     */
    async getForks(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/forks`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Create a fork for the authenticated user.
  
  **Note**: Forking a Repository happens asynchronously. You may have to wait a short period of time before you can access the git objects. If this takes longer than 5 minutes, be sure to contact [GitHub Support](https://support.github.com/contact?tags=dotcom-rest-api).
  * Documentation: https://docs.github.com/en/rest/reference/repos#create-a-fork
  * @param options Request options.
  */
    async createFork(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/forks`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DeploymentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Status = new DeploymentStatusGroup(implementation, this.getGlobalErrorStrategy);
        this.Key = new DeploymentKeyGroup(implementation, this.getGlobalErrorStrategy);
        this.Environment = new DeploymentEnvironmentGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Simple filtering of deployments is available via query parameters:
     * Documentation: https://docs.github.com/en/rest/reference/deployments#list-deployments
     * @param options Request options.
     */
    async getDeployments(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deployments offer a few configurable parameters with certain defaults.
  
  The `ref` parameter can be any named branch, tag, or SHA. At GitHub we often deploy branches and verify them
  before we merge a pull request.
  
  The `environment` parameter allows deployments to be issued to different runtime environments. Teams often have
  multiple environments for verifying their applications, such as `production`, `staging`, and `qa`. This parameter
  makes it easier to track which environments have requested deployments. The default environment is `production`.
  
  The `auto_merge` parameter is used to ensure that the requested ref is not behind the repository's default branch. If
  the ref _is_ behind the default branch for the repository, we will attempt to merge it for you. If the merge succeeds,
  the API will return a successful merge commit. If merge conflicts prevent the merge from succeeding, the API will
  return a failure response.
  
  By default, [commit statuses](https://docs.github.com/rest/commits/statuses) for every submitted context must be in a `success`
  state. The `required_contexts` parameter allows you to specify a subset of contexts that must be `success`, or to
  specify contexts that have not yet been submitted. You are not required to use commit statuses to deploy. If you do
  not require any contexts or create any commit statuses, the deployment will always succeed.
  
  The `payload` parameter is available for any extra information that a deployment system might need. It is a JSON text
  field that will be passed on when a deployment event is dispatched.
  
  The `task` parameter is used by the deployment system to allow different execution paths. In the web world this might
  be `deploy:migrations` to run schema changes on the system. In the compiled world this could be a flag to compile an
  application with debugging enabled.
  
  Users with `repo` or `repo_deployment` scopes can create a deployment for a given ref.
  
  #### Merged branch response
  You will see this response when GitHub automatically merges the base branch into the topic branch instead of creating
  a deployment. This auto-merge happens when:
  *   Auto-merge option is enabled in the repository
  *   Topic branch does not include the latest changes on the base branch, which is `master` in the response example
  *   There are no merge conflicts
  
  If there are no new commits in the base branch, a new request to create a deployment should give a successful
  response.
  
  #### Merge conflict response
  This error happens when the `auto_merge` option is enabled and when the default branch (in this case `master`), can't
  be merged into the branch that's being deployed (in this case `topic-branch`), due to merge conflicts.
  
  #### Failed commit status checks
  This error happens when the `required_contexts` parameter indicates that one or more contexts need to have a `success`
  status for the commit to be deployed, but one or more of the required contexts do not have a state of `success`.
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-a-deployment
  * @param options Request options.
  */
    async createDeployment(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/deployments#get-a-deployment
     * @param options Request options.
     */
    async getDeployment(options) {
        const { headers, errorStrategy, owner, repo, deployment_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments/${encodeURIComponent(deployment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * If the repository only has one deployment, you can delete the deployment regardless of its status. If the repository has more than one deployment, you can only delete inactive deployments. This ensures that repositories with multiple deployments will always have an active deployment. Anyone with `repo` or `repo_deployment` scopes can delete a deployment.
  
  To set a deployment as inactive, you must:
  
  *   Create a new deployment that is active so that the system has a record of the current state, then delete the previously active deployment.
  *   Mark the active deployment as inactive by adding any non-successful deployment status.
  
  For more information, see "[Create a deployment](https://docs.github.com/rest/deployments/deployments/#create-a-deployment)" and "[Create a deployment status](https://docs.github.com/rest/deployments/deployment-statuses#create-a-deployment-status)."
  * Documentation: https://docs.github.com/en/rest/reference/deployments#delete-a-deployment
  * @param options Request options.
  */
    async deleteDeployment(options) {
        const { headers, errorStrategy, owner, repo, deployment_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments/${encodeURIComponent(deployment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class DeploymentStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Users with pull access can view deployment statuses for a deployment:
     * Documentation: https://docs.github.com/en/rest/reference/deployments#list-deployment-statuses
     * @param options Request options.
     */
    async getStatuses(options) {
        const { headers, errorStrategy, owner, repo, deployment_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments/${encodeURIComponent(deployment_id)}/statuses`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Users with `push` access can create deployment statuses for a given deployment.
  
  GitHub Apps require `read & write` access to "Deployments" and `read-only` access to "Repo contents" (for private repos). OAuth Apps require the `repo_deployment` scope.
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-a-deployment-status
  * @param options Request options.
  */
    async createStatus(options) {
        const { body, headers, errorStrategy, owner, repo, deployment_id } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments/${encodeURIComponent(deployment_id)}/statuses`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Users with pull access can view a deployment status for a deployment:
     * Documentation: https://docs.github.com/en/rest/reference/deployments#get-a-deployment-status
     * @param options Request options.
     */
    async getStatus(options) {
        const { headers, errorStrategy, owner, repo, deployment_id, status_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/deployments/${encodeURIComponent(deployment_id)}/statuses/${encodeURIComponent(status_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DeploymentKeyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#list-deploy-keys
     * @param options Request options.
     */
    async getKeys(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/keys`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * You can create a read-only deploy key.
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#create-a-deploy-key
     * @param options Request options.
     */
    async createKey(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/keys`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#get-a-deploy-key
     * @param options Request options.
     */
    async getKey(options) {
        const { headers, errorStrategy, owner, repo, key_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/keys/${encodeURIComponent(key_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deploy keys are immutable. If you need to update a key, remove the key and create a new one instead.
     * Documentation: https://docs.github.com/en/rest/reference/deploy_keys#delete-a-deploy-key
     * @param options Request options.
     */
    async deleteKey(options) {
        const { headers, errorStrategy, owner, repo, key_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/keys/${encodeURIComponent(key_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class DeploymentEnvironmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Get all environments for a repository.
  
  Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/deployments#get-all-environments
  * @param options Request options.
  */
    async getEnvironments(options) {
        const { headers, errorStrategy, owner, repo } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/environments`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * **Note:** To get information about name patterns that branches must match in order to deploy to this environment, see "[Get a deployment branch policy](/rest/deployments/branch-policies#get-a-deployment-branch-policy)."
  
  Anyone with read access to the repository can use this endpoint. If the
  repository is private, you must use an access token with the `repo` scope. GitHub
  Apps must have the `actions:read` permission to use this endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/deployments#get-an-environment
  * @param options Request options.
  */
    async getEnvironment(options) {
        const { headers, errorStrategy, owner, repo, environment_name } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/environments/${encodeURIComponent(environment_name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Create or update an environment with protection rules, such as required reviewers. For more information about environment protection rules, see "[Environments](/actions/reference/environments#environment-protection-rules)."
  
  **Note:** To create or update name patterns that branches must match in order to deploy to this environment, see "[Deployment branch policies](/rest/deployments/branch-policies)."
  
  **Note:** To create or update secrets for an environment, see "[Secrets](/rest/reference/actions#secrets)."
  
  You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration:write` permission for the repository to use this endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/deployments#create-or-update-an-environment
  * @param options Request options.
  */
    async createOrUpdateEnvironment(options) {
        const { body, headers, errorStrategy, owner, repo, environment_name } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/environments/${encodeURIComponent(environment_name)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * You must authenticate using an access token with the repo scope to use this endpoint.
     * Documentation: https://docs.github.com/en/rest/reference/deployments#delete-an-environment
     * @param options Request options.
     */
    async deleteEnvironment(options) {
        const { headers, errorStrategy, owner, repo, environment_name } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/environments/${encodeURIComponent(environment_name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class BranchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Protection = new BranchProtectionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/branches#list-branches
     * @param options Request options.
     */
    async getBranches(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-a-branch
     * @param options Request options.
     */
    async getBranch(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Renames a branch in a repository.
  
  **Note:** Although the API responds immediately, the branch rename process might take some extra time to complete in the background. You won't be able to push to the old branch name while the rename process is in progress. For more information, see "[Renaming a branch](https://docs.github.com/github/administering-a-repository/renaming-a-branch)".
  
  The permissions required to use this endpoint depends on whether you are renaming the default branch.
  
  To rename a non-default branch:
  
  * Users must have push access.
  * GitHub Apps must have the `contents:write` repository permission.
  
  To rename the default branch:
  
  * Users must have admin or owner permissions.
  * GitHub Apps must have the `administration:write` repository permission.
  * Documentation: https://docs.github.com/en/rest/reference/branches#rename-a-branch
  * @param options Request options.
  */
    async renameBranch(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/rename`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sync a branch of a forked repository to keep it up-to-date with the upstream repository.
     * Documentation: https://docs.github.com/en/rest/reference/branches#sync-a-fork-branch-with-the-upstream-repository
     * @param options Request options.
     */
    async syncForkBranch(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/merge-upstream`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/branches#merge-a-branch
     * @param options Request options.
     */
    async mergeBranch(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/merges`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class BranchProtectionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Admin = new BranchProtectionAdminGroup(implementation, this.getGlobalErrorStrategy);
        this.Pull = new BranchProtectionPullGroup(implementation, this.getGlobalErrorStrategy);
        this.Commit = new BranchProtectionCommitGroup(implementation, this.getGlobalErrorStrategy);
        this.Status = new BranchProtectionStatusGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-branch-protection
     * @param options Request options.
     */
    async getProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Protecting a branch requires admin or owner permissions to the repository.
  
  **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
  
  **Note**: The list of users, apps, and teams in total is limited to 100 items.
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-branch-protection
  * @param options Request options.
  */
    async updateProtection(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#delete-branch-protection
     * @param options Request options.
     */
    async deleteProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class BranchProtectionAdminGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-admin-branch-protection
     * @param options Request options.
     */
    async getProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/enforce_admins`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Adding admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  * Documentation: https://docs.github.com/en/rest/reference/branches#set-admin-branch-protection
  * @param options Request options.
  */
    async setProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/enforce_admins`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Removing admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  * Documentation: https://docs.github.com/en/rest/reference/branches#delete-admin-branch-protection
  * @param options Request options.
  */
    async deleteProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/enforce_admins`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class BranchProtectionPullGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Review = new BranchProtectionPullReviewGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class BranchProtectionPullReviewGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-pull-request-review-protection
     * @param options Request options.
     */
    async getProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_pull_request_reviews`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Updating pull request review enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
  
  **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-pull-request-review-protection
  * @param options Request options.
  */
    async updateProtection(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_pull_request_reviews`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class BranchProtectionCommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Signature = new BranchProtectionCommitSignatureGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class BranchProtectionCommitSignatureGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to check whether a branch requires signed commits. An enabled status of `true` indicates you must sign commits on this branch. For more information, see [Signing commits with GPG](https://docs.github.com/articles/signing-commits-with-gpg) in GitHub Help.
  
  **Note**: You must enable branch protection to require signed commits.
  * Documentation: https://docs.github.com/en/rest/reference/branches#get-commit-signature-protection
  * @param options Request options.
  */
    async getProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_signatures`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to require signed commits on a branch. You must enable branch protection to require signed commits.
  * Documentation: https://docs.github.com/en/rest/reference/branches#create-commit-signature-protection
  * @param options Request options.
  */
    async createProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_signatures`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  When authenticated with admin or owner permissions to the repository, you can use this endpoint to disable required signed commits on a branch. You must enable branch protection to require signed commits.
  * Documentation: https://docs.github.com/en/rest/reference/branches#delete-commit-signature-protection
  * @param options Request options.
  */
    async deleteProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_signatures`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class BranchProtectionStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Check = new BranchProtectionStatusCheckGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class BranchProtectionStatusCheckGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-status-checks-protection
     * @param options Request options.
     */
    async getProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Updating required status checks requires admin or owner permissions to the repository and branch protection to be enabled.
  * Documentation: https://docs.github.com/en/rest/reference/branches#update-status-check-protection
  * @param options Request options.
  */
    async updateProtection(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#remove-status-check-protection
     * @param options Request options.
     */
    async removeProtection(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#get-all-status-check-contexts
     * @param options Request options.
     */
    async getContexts(options) {
        const { headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks/contexts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#add-status-check-contexts
     * @param options Request options.
     */
    async addContexts(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks/contexts`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#set-status-check-contexts
     * @param options Request options.
     */
    async setContexts(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks/contexts`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
     * Documentation: https://docs.github.com/en/rest/reference/branches#remove-status-check-contexts
     * @param options Request options.
     */
    async removeContexts(options) {
        const { body, headers, errorStrategy, owner, repo, branch } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/branches/${encodeURIComponent(branch)}/protection/required_status_checks/contexts`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class GitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Reference = new GitReferenceGroup(implementation, this.getGlobalErrorStrategy);
        this.Blob = new GitBlobGroup(implementation, this.getGlobalErrorStrategy);
        this.Tag = new GitTagGroup(implementation, this.getGlobalErrorStrategy);
        this.Tree = new GitTreeGroup(implementation, this.getGlobalErrorStrategy);
        this.Commit = new GitCommitGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class GitReferenceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns an array of references from your Git database that match the supplied name. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't exist in the repository, but existing refs start with `:ref`, they will be returned as an array.
  
  When you use this endpoint without providing a `:ref`, it will return an array of all the references from your Git database, including notes and stashes if they exist on the server. Anything in the namespace is returned, not just `heads` and `tags`.
  
  **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  
  If you request matching references for a branch named `feature` but the branch `feature` doesn't exist, the response can still include other matching head refs that start with the word `feature`, such as `featureA` and `featureB`.
  * Documentation: https://docs.github.com/en/rest/reference/git#list-matching-references
  * @param options Request options.
  */
    async getMatchingReferences(options) {
        const { headers, errorStrategy, owner, repo, ref } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/matching-refs/${encodeURIComponent(ref)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a single reference from your Git database. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't match an existing ref, a `404` is returned.
  
  **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-reference
  * @param options Request options.
  */
    async getReference(options) {
        const { headers, errorStrategy, owner, repo, ref } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/ref/${encodeURIComponent(ref)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a reference for your repository. You are unable to create new references for empty repositories, even if the commit SHA-1 hash used exists. Empty repositories are repositories without branches.
     * Documentation: https://docs.github.com/en/rest/reference/git#create-a-reference
     * @param options Request options.
     */
    async createReference(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/refs`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/git#update-a-reference
     * @param options Request options.
     */
    async updateReference(options) {
        const { body, headers, errorStrategy, owner, repo, ref } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/refs/${encodeURIComponent(ref)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/git#delete-a-reference
     * @param options Request options.
     */
    async deleteReference(options) {
        const { headers, errorStrategy, owner, repo, ref } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/refs/${encodeURIComponent(ref)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class GitBlobGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/git#create-a-blob
     * @param options Request options.
     */
    async createBlob(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/blobs`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * The `content` in the response will always be Base64 encoded.
  
  _Note_: This API supports blobs up to 100 megabytes in size.
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-blob
  * @param options Request options.
  */
    async getBlob(options) {
        const { headers, errorStrategy, owner, repo, file_sha } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/blobs/${encodeURIComponent(file_sha)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GitTagGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Note that creating a tag object does not create the reference that makes a tag in Git. If you want to create an annotated tag in Git, you have to do this call to create the tag object, and then [create](https://docs.github.com/rest/reference/git#create-a-reference) the `refs/tags/[tag]` reference. If you want to create a lightweight tag, you only have to [create](https://docs.github.com/rest/reference/git#create-a-reference) the tag reference - this call would be unnecessary.
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-tag-object
  * @param options Request options.
  */
    async createTag(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/tags`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-tag
  * @param options Request options.
  */
    async getTag(options) {
        const { headers, errorStrategy, owner, repo, tag_sha } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/tags/${encodeURIComponent(tag_sha)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GitTreeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * The tree creation API accepts nested entries. If you specify both a tree and a nested path modifying that tree, this endpoint will overwrite the contents of the tree with the new path contents, and create a new tree structure.
  
  If you use this endpoint to add, delete, or modify the file contents in a tree, you will need to commit the tree and then update a branch to point to the commit. For more information see "[Create a commit](https://docs.github.com/rest/reference/git#create-a-commit)" and "[Update a reference](https://docs.github.com/rest/reference/git#update-a-reference)."
  
  Returns an error if you try to delete a file that does not exist.
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-tree
  * @param options Request options.
  */
    async createTree(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/trees`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a single tree using the SHA1 value for that tree.
  
  If `truncated` is `true` in the response then the number of items in the `tree` array exceeded our maximum limit. If you need to fetch more items, use the non-recursive method of fetching trees, and fetch one sub-tree at a time.
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-tree
  * @param options Request options.
  */
    async getTree(options) {
        const { headers, errorStrategy, owner, repo, tree_sha, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/trees/${encodeURIComponent(tree_sha)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GitCommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a new Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/git#create-a-commit
  * @param options Request options.
  */
    async createCommit(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/commits`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets a Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/git#get-a-commit
  * @param options Request options.
  */
    async getCommit(options) {
        const { headers, errorStrategy, owner, repo, commit_sha } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/git/commits/${encodeURIComponent(commit_sha)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Comment = new CommitCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Status = new CommitStatusGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commits
  * @param options Request options.
  */
    async getCommits(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
  
  Returns all branches where the given commit SHA is the HEAD, or latest commit for the branch.
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-branches-for-head-commit
  * @param options Request options.
  */
    async getBranchesForHead(options) {
        const { headers, errorStrategy, owner, repo, commit_sha } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(commit_sha)}/branches-where-head`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Lists the merged pull request that introduced the commit to the repository. If the commit is not present in the default branch, additionally returns open pull requests associated with the commit. The results may include open and closed pull requests. Additional preview headers may be required to see certain details for associated pull requests, such as whether a pull request is in a draft state. For more information about previews that might affect this endpoint, see the [List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests) endpoint.
     * Documentation: https://docs.github.com/en/rest/reference/commits#list-pull-requests-associated-with-a-commit
     * @param options Request options.
     */
    async getPullRequestsForCommit(options) {
        const { headers, errorStrategy, owner, repo, commit_sha } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(commit_sha)}/pulls`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the contents of a single commit reference. You must have `read` access for the repository to use this endpoint.
  
  **Note:** If there are more than 300 files in the commit diff, the response will include pagination link headers for the remaining files, up to a limit of 3000 files. Each page contains the static commit information, and the only changes are to the file listing.
  
  You can pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to  fetch `diff` and `patch` formats. Diffs with binary data will have no `patch` property.
  
  To return only the SHA-1 hash of the commit reference, you can provide the `sha` custom [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) in the `Accept` header. You can use this endpoint to check if a remote reference's SHA-1 hash is the same as your local reference's SHA-1 hash by providing the local SHA-1 reference as the ETag.
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/commits#get-a-commit
  * @param options Request options.
  */
    async getCommit(options) {
        const { headers, errorStrategy, owner, repo, ref, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(ref)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Compares two commits against one another. You can compare branches in the same repository, or you can compare branches that exist in different repositories within the same repository network, including fork branches. For more information about how to view a repository's network, see "[Understanding connections between repositories](https://docs.github.com/repositories/viewing-activity-and-data-for-your-repository/understanding-connections-between-repositories)."
  
  This endpoint is equivalent to running the `git log BASE..HEAD` command, but it returns commits in a different order. The `git log BASE..HEAD` command returns commits in reverse chronological order, whereas the API returns commits in chronological order. You can pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
  
  The API response includes details about the files that were changed between the two commits. This includes the status of the change (if a file was added, removed, modified, or renamed), and details of the change itself. For example, files with a `renamed` status have a `previous_filename` field showing the previous filename of the file, and files with a `modified` status have a `patch` field showing the changes made to the file.
  
  When calling this endpoint without any paging parameter (`per_page` or `page`), the returned list is limited to 250 commits, and the last commit in the list is the most recent of the entire comparison.
  
  **Working with large comparisons**
  
  To process a response with a large number of commits, use a query parameter (`per_page` or `page`) to paginate the results. When using pagination:
  
  - The list of changed files is only shown on the first page of results, but it includes all changed files for the entire comparison.
  - The results are returned in chronological order, but the last commit in the returned list may not be the most recent one in the entire set if there are more pages of results.
  
  For more information on working with pagination, see "[Using pagination in the REST API](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api)."
  
  **Signature verification object**
  
  The response will include a `verification` object that describes the result of verifying the commit's signature. The `verification` object includes the following fields:
  
  | Name | Type | Description |
  | ---- | ---- | ----------- |
  | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
  | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
  | `signature` | `string` | The signature that was extracted from the commit. |
  | `payload` | `string` | The value that was signed. |
  
  These are the possible values for `reason` in the `verification` object:
  
  | Value | Description |
  | ----- | ----------- |
  | `expired_key` | The key that made the signature is expired. |
  | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
  | `gpgverify_error` | There was an error communicating with the signature verification service. |
  | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
  | `unsigned` | The object does not include a signature. |
  | `unknown_signature_type` | A non-PGP signature was found in the commit. |
  | `no_user` | No user was associated with the `committer` email address in the commit. |
  | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on their account. |
  | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
  | `unknown_key` | The key that made the signature has not been registered with any user's account. |
  | `malformed_signature` | There was an error parsing the signature. |
  | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
  | `valid` | None of the above errors applied, so the signature is considered to be verified. |
  * Documentation: https://docs.github.com/en/rest/reference/commits#compare-two-commits
  * @param options Request options.
  */
    async compareCommits(options) {
        const { headers, errorStrategy, owner, repo, basehead, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/compare/${encodeURIComponent(basehead)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommitCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Commit Comments use [these custom media types](https://docs.github.com/rest/reference/repos#custom-media-types). You can read more about the use of media types in the API [here](https://docs.github.com/rest/overview/media-types/).
  
  Comments are ordered by ascending ID.
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-comments-for-a-repository
  * @param options Request options.
  */
    async getCommentsForRepository(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/commits#get-a-commit-comment
     * @param options Request options.
     */
    async getComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/commits#update-a-commit-comment
     * @param options Request options.
     */
    async updateComment(options) {
        const { body, headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/commits#delete-a-commit-comment
     * @param options Request options.
     */
    async deleteComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Use the `:commit_sha` to specify the commit that will have its comments listed.
     * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-comments
     * @param options Request options.
     */
    async getComments(options) {
        const { headers, errorStrategy, owner, repo, commit_sha, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(commit_sha)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Create a comment for a commit using its `:commit_sha`.
  
  This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/commits#create-a-commit-comment
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy, owner, repo, commit_sha } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(commit_sha)}/comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommitStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Users with pull access in a repository can access a combined view of commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name.
  
  
  Additionally, a combined `state` is returned. The `state` is one of:
  
  *   **failure** if any of the contexts report as `error` or `failure`
  *   **pending** if there are no statuses or a context is `pending`
  *   **success** if the latest status for all contexts is `success`
  * Documentation: https://docs.github.com/en/rest/reference/commits#get-the-combined-status-for-a-specific-reference
  * @param options Request options.
  */
    async getCombinedStatusForReference(options) {
        const { headers, errorStrategy, owner, repo, ref, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(ref)}/status`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Users with pull access in a repository can view commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name. Statuses are returned in reverse chronological order. The first status in the list will be the latest one.
  
  This resource is also available via a legacy route: `GET /repos/:owner/:repo/statuses/:ref`.
  * Documentation: https://docs.github.com/en/rest/reference/commits#list-commit-statuses-for-a-reference
  * @param options Request options.
  */
    async getStatusesForReference(options) {
        const { headers, errorStrategy, owner, repo, ref, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/commits/${encodeURIComponent(ref)}/statuses`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Users with push access in a repository can create commit statuses for a given SHA.
  
  Note: there is a limit of 1000 statuses per `sha` and `context` within a repository. Attempts to create more than 1000 statuses will result in a validation error.
  * Documentation: https://docs.github.com/en/rest/reference/commits#create-a-commit-status
  * @param options Request options.
  */
    async createStatus(options) {
        const { body, headers, errorStrategy, owner, repo, sha } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/statuses/${encodeURIComponent(sha)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Comment = new IssueCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Milestone = new IssueMilestoneGroup(implementation, this.getGlobalErrorStrategy);
        this.Assignee = new IssueAssigneeGroup(implementation, this.getGlobalErrorStrategy);
        this.Label = new IssueLabelGroup(implementation, this.getGlobalErrorStrategy);
        this.Event = new IssueEventGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * List issues across owned and member repositories assigned to the authenticated user.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user
  * @param options Request options.
  */
    async getIssuesForAuthenticatedUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/user/issues`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * List issues in an organization assigned to the authenticated user.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user
  * @param options Request options.
  */
    async getOrganizationIssuesForAuthenticatedUser(options) {
        const { headers, errorStrategy, org, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/orgs/${encodeURIComponent(org)}/issues`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * List issues in a repository. Only open issues will be listed.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-repository-issues
  * @param options Request options.
  */
    async getRepositoryIssues(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Any user with pull access to a repository can create an issue. If [issues are disabled in the repository](https://docs.github.com/articles/disabling-issues/), the API returns a `410 Gone` status.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
  * Documentation: https://docs.github.com/en/rest/reference/issues#create-an-issue
  * @param options Request options.
  */
    async createIssue(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * The API returns a [`301 Moved Permanently` status](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-redirects-redirects) if the issue was
  [transferred](https://docs.github.com/articles/transferring-an-issue-to-another-repository/) to another repository. If
  the issue was transferred to or deleted from a repository where the authenticated user lacks read access, the API
  returns a `404 Not Found` status. If the issue was deleted from a repository where the authenticated user has read
  access, the API returns a `410 Gone` status. To receive webhook events for transferred and deleted issues, subscribe
  to the [`issues`](https://docs.github.com/webhooks/event-payloads/#issues) webhook.
  
  **Note**: GitHub's REST API considers every pull request an issue, but not every issue is a pull request. For this
  reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
  the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
  request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
  * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue
  * @param options Request options.
  */
    async getIssue(options) {
        const { headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Issue owners and users with push access can edit an issue.
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-an-issue
     * @param options Request options.
     */
    async updateIssue(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Users with push access can lock an issue or pull request's conversation.
  
  Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
  * Documentation: https://docs.github.com/en/rest/reference/issues#lock-an-issue
  * @param options Request options.
  */
    async lockIssue(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/lock`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Users with push access can unlock an issue's conversation.
     * Documentation: https://docs.github.com/en/rest/reference/issues#unlock-an-issue
     * @param options Request options.
     */
    async unlockIssue(options) {
        const { headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/lock`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * You can use the REST API to list comments on issues and pull requests for a repository. Every pull request is an issue, but not every issue is a pull request.
  
  By default, issue comments are ordered by ascending ID.
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-comments-for-a-repository
  * @param options Request options.
  */
    async getCommentsForRepository(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * You can use the REST API to get comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue-comment
     * @param options Request options.
     */
    async getComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * You can use the REST API to update comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-an-issue-comment
     * @param options Request options.
     */
    async updateComment(options) {
        const { body, headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/comments/${encodeURIComponent(comment_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * You can use the REST API to delete comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-an-issue-comment
     * @param options Request options.
     */
    async deleteComment(options) {
        const { headers, errorStrategy, owner, repo, comment_id } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * You can use the REST API to list comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
  
  Issue comments are ordered by ascending ID.
  * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-comments
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, owner, repo, issue_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  *
  You can use the REST API to create comments on issues and pull requests. Every pull request is an issue, but not every issue is a pull request.
  
  This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications).
  Creating content too quickly using this endpoint may result in secondary rate limiting.
  See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)"
  and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)"
  for details.
  * Documentation: https://docs.github.com/en/rest/reference/issues#create-an-issue-comment
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueMilestoneGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-milestones
     * @param options Request options.
     */
    async getMilestones(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#create-a-milestone
     * @param options Request options.
     */
    async createMilestone(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-a-milestone
     * @param options Request options.
     */
    async getMilestone(options) {
        const { headers, errorStrategy, owner, repo, milestone_number } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones/${encodeURIComponent(milestone_number)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-a-milestone
     * @param options Request options.
     */
    async updateMilestone(options) {
        const { body, headers, errorStrategy, owner, repo, milestone_number } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones/${encodeURIComponent(milestone_number)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-a-milestone
     * @param options Request options.
     */
    async deleteMilestone(options) {
        const { headers, errorStrategy, owner, repo, milestone_number } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones/${encodeURIComponent(milestone_number)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueAssigneeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Lists the [available assignees](https://docs.github.com/articles/assigning-issues-and-pull-requests-to-other-github-users/) for issues in a repository.
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-assignees
     * @param options Request options.
     */
    async getAssignees(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/assignees`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Checks if a user has permission to be assigned to an issue in this repository.
  
  If the `assignee` can be assigned to issues in the repository, a `204` header with no content is returned.
  
  Otherwise a `404` status code is returned.
  * Documentation: https://docs.github.com/en/rest/reference/issues#check-if-a-user-can-be-assigned
  * @param options Request options.
  */
    async canUserBeAssigned(options) {
        const { headers, errorStrategy, owner, repo, assignee } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/assignees/${encodeURIComponent(assignee)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Adds up to 10 assignees to an issue. Users already assigned to an issue are not replaced.
     * Documentation: https://docs.github.com/en/rest/reference/issues#add-assignees-to-an-issue
     * @param options Request options.
     */
    async addAssignees(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/assignees`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes one or more assignees from an issue.
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-assignees-from-an-issue
     * @param options Request options.
     */
    async removeAssignees(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/assignees`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueLabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-an-issue
     * @param options Request options.
     */
    async getLabels(options) {
        const { headers, errorStrategy, owner, repo, issue_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#add-labels-to-an-issue
     * @param options Request options.
     */
    async addLabelsToIssue(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/labels`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes any previous labels and sets the new labels for an issue.
     * Documentation: https://docs.github.com/en/rest/reference/issues#set-labels-for-an-issue
     * @param options Request options.
     */
    async setLabelsToIssue(options) {
        const { body, headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("PUT", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/labels`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-all-labels-from-an-issue
     * @param options Request options.
     */
    async removeLabelsFromIssue(options) {
        const { headers, errorStrategy, owner, repo, issue_number } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/labels`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Removes the specified label from the issue, and returns the remaining labels on the issue. This endpoint returns a `404 Not Found` status if the label does not exist.
     * Documentation: https://docs.github.com/en/rest/reference/issues#remove-a-label-from-an-issue
     * @param options Request options.
     */
    async removeLabelFromIssue(options) {
        const { headers, errorStrategy, owner, repo, issue_number, name } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/labels/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-a-repository
     * @param options Request options.
     */
    async getLabelsForRepository(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#create-a-label
     * @param options Request options.
     */
    async createLabel(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/labels`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-a-label
     * @param options Request options.
     */
    async getLabel(options) {
        const { headers, errorStrategy, owner, repo, name } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/labels/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#update-a-label
     * @param options Request options.
     */
    async updateLabel(options) {
        const { body, headers, errorStrategy, owner, repo, name } = options;
        const request = new Request("PATCH", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/labels/${encodeURIComponent(name)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#delete-a-label
     * @param options Request options.
     */
    async deleteLabel(options) {
        const { headers, errorStrategy, owner, repo, name } = options;
        const request = new Request("DELETE", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/labels/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-labels-for-issues-in-a-milestone
     * @param options Request options.
     */
    async getLabelsForIssuesInMilestone(options) {
        const { headers, errorStrategy, owner, repo, milestone_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/milestones/${encodeURIComponent(milestone_number)}/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueEventGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-events-for-a-repository
     * @param options Request options.
     */
    async getEventsForRepository(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/events`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#get-an-issue-event
     * @param options Request options.
     */
    async getEvent(options) {
        const { headers, errorStrategy, owner, repo, event_id } = options;
        const request = new Request("GET", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/events/${encodeURIComponent(event_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/issues#list-issue-events
     * @param options Request options.
     */
    async getEvents(options) {
        const { headers, errorStrategy, owner, repo, issue_number, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/issues/${encodeURIComponent(issue_number)}/events`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Lists the projects in an organization. Returns a `404 Not Found` status if projects are disabled in the organization. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-organization-projects
     * @param options Request options.
     */
    async getOrganizationProjects(options) {
        const { headers, errorStrategy, org, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/orgs/${encodeURIComponent(org)}/projects`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates an organization project board. Returns a `410 Gone` status if projects are disabled in the organization or if the organization does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-an-organization-project
     * @param options Request options.
     */
    async createOrganizationProject(options) {
        const { body, headers, errorStrategy, org } = options;
        const request = new Request("POST", `/orgs/${encodeURIComponent(org)}/projects`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets a project by its `id`. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#get-a-project
     * @param options Request options.
     */
    async getProject(options) {
        const { headers, errorStrategy, project_id } = options;
        const request = new Request("GET", `/projects/${encodeURIComponent(project_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates a project board's information. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#update-a-project
     * @param options Request options.
     */
    async updateProject(options) {
        const { body, headers, errorStrategy, project_id } = options;
        const request = new Request("PATCH", `/projects/${encodeURIComponent(project_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a project board. Returns a `404 Not Found` status if projects are disabled.
     * Documentation: https://docs.github.com/en/rest/reference/projects#delete-a-project
     * @param options Request options.
     */
    async deleteProject(options) {
        const { headers, errorStrategy, project_id } = options;
        const request = new Request("DELETE", `/projects/${encodeURIComponent(project_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Lists the projects in a repository. Returns a `404 Not Found` status if projects are disabled in the repository. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-repository-projects
     * @param options Request options.
     */
    async getRepositoryProjects(options) {
        const { headers, errorStrategy, owner, repo, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/projects`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a repository project board. Returns a `410 Gone` status if projects are disabled in the repository or if the repository does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-a-repository-project
     * @param options Request options.
     */
    async createRepositoryProject(options) {
        const { body, headers, errorStrategy, owner, repo } = options;
        const request = new Request("POST", `/repos/${encodeURIComponent(owner)}/${encodeURIComponent(repo)}/projects`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     *
     * Documentation: https://docs.github.com/en/rest/reference/projects#list-user-projects
     * @param options Request options.
     */
    async getUserProjects(options) {
        const { headers, errorStrategy, username, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/users/${encodeURIComponent(username)}/projects`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a user project board. Returns a `410 Gone` status if the user does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
     * Documentation: https://docs.github.com/en/rest/reference/projects#create-a-user-project
     * @param options Request options.
     */
    async createUserProject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/user/projects`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Searches for query terms inside of a file. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for code, you can get text match metadata for the file **content** and file **path** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find the definition of the `addClass` function inside [jQuery](https://github.com/jquery/jquery) repository, your query would look something like this:
  
  `q=addClass+in:file+language:js+repo:jquery/jquery`
  
  This query searches for the keyword `addClass` within a file's contents. The query limits the search to files where the language is JavaScript in the `jquery/jquery` repository.
  
  #### Considerations for code search
  
  Due to the complexity of searching code, there are a few restrictions on how searches are performed:
  
  *   Only the _default branch_ is considered. In most cases, this will be the `master` branch.
  *   Only files smaller than 384 KB are searchable.
  *   You must always include at least one search term when searching source code. For example, searching for [`language:go`](https://github.com/search?utf8=%E2%9C%93&q=language%3Ago&type=Code) is not valid, while [`amazing
  language:go`](https://github.com/search?utf8=%E2%9C%93&q=amazing+language%3Ago&type=Code) is.
  
  **Note:** Starting on April 10, 2023, code search on GitHub.com will have a separate
  rate limit from other search types, of 10 requests per minute, and all code
  search requests will require authentication. For more information, see [this blog post](https://github.blog/changelog/2023-03-10-changes-to-the-code-search-api/).
  * Documentation: https://docs.github.com/en/rest/reference/search#search-code
  * @param options Request options.
  */
    async searchCode(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/code`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find commits via various criteria on the default branch (usually `main`). This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for commits, you can get text match metadata for the **message** field when you provide the `text-match` media type. For more details about how to receive highlighted search results, see [Text match
  metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find commits related to CSS in the [octocat/Spoon-Knife](https://github.com/octocat/Spoon-Knife) repository. Your query would look something like this:
  
  `q=repo:octocat/Spoon-Knife+css`
  * Documentation: https://docs.github.com/en/rest/reference/search#search-commits
  * @param options Request options.
  */
    async searchCommits(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/commits`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find issues by state and keyword. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for issues, you can get text match metadata for the issue **title**, issue **body**, and issue **comment body** fields when you pass the `text-match` media type. For more details about how to receive highlighted
  search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find the oldest unresolved Python bugs on Windows. Your query might look something like this.
  
  `q=windows+label:bug+language:python+state:open&sort=created&order=asc`
  
  This query searches for the keyword `windows`, within any open issue that is labeled as `bug`. The search runs across repositories whose primary language is Python. The results are sorted by creation date in ascending order, which means the oldest issues appear first in the search results.
  
  **Note:** For [user-to-server](https://docs.github.com/developers/apps/identifying-and-authorizing-users-for-github-apps#user-to-server-requests) GitHub App requests, you can't retrieve a combination of issues and pull requests in a single query. Requests that don't include the `is:issue` or `is:pull-request` qualifier will receive an HTTP `422 Unprocessable Entity` response. To get results for both issues and pull requests, you must send separate queries for issues and pull requests. For more information about the `is` qualifier, see "[Searching only issues or pull requests](https://docs.github.com/github/searching-for-information-on-github/searching-issues-and-pull-requests#search-only-issues-or-pull-requests)."
  * Documentation: https://docs.github.com/en/rest/reference/search#search-issues-and-pull-requests
  * @param options Request options.
  */
    async searchIssuesAndPullRequests(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/issues`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find labels in a repository with names or descriptions that match search keywords. Returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for labels, you can get text match metadata for the label **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to find labels in the `linguist` repository that match `bug`, `defect`, or `enhancement`. Your query might look like this:
  
  `q=bug+defect+enhancement&repository_id=64778136`
  
  The labels that best match the query appear first in the search results.
  * Documentation: https://docs.github.com/en/rest/reference/search#search-labels
  * @param options Request options.
  */
    async searchLabels(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/labels`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find repositories via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for repositories, you can get text match metadata for the **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to search for popular Tetris repositories written in assembly code, your query might look like this:
  
  `q=tetris+language:assembly&sort=stars&order=desc`
  
  This query searches for repositories with the word `tetris` in the name, the description, or the README. The results are limited to repositories where the primary language is assembly. The results are sorted by stars in descending order, so that the most popular repositories appear first in the search results.
  * Documentation: https://docs.github.com/en/rest/reference/search#search-repositories
  * @param options Request options.
  */
    async searchRepositories(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/repositories`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find topics via various criteria. Results are sorted by best match. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination). See "[Searching topics](https://docs.github.com/articles/searching-topics/)" for a detailed list of qualifiers.
  
  When searching for topics, you can get text match metadata for the topic's **short\_description**, **description**, **name**, or **display\_name** field when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you want to search for topics related to Ruby that are featured on https://github.com/topics. Your query might look like this:
  
  `q=ruby+is:featured`
  
  This query searches for topics with the keyword `ruby` and limits the results to find only topics that are featured. The topics that are the best match for the query appear first in the search results.
  * Documentation: https://docs.github.com/en/rest/reference/search#search-topics
  * @param options Request options.
  */
    async searchTopics(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/topics`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find users via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
  
  When searching for users, you can get text match metadata for the issue **login**, public **email**, and **name** fields when you pass the `text-match` media type. For more details about highlighting search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata). For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
  
  For example, if you're looking for a list of popular users, you might try this query:
  
  `q=tom+repos:%3E42+followers:%3E1000`
  
  This query searches for users with the name `tom`. The results are restricted to users with more than 42 repositories and over 1,000 followers.
  * Documentation: https://docs.github.com/en/rest/reference/search#search-users
  * @param options Request options.
  */
    async searchUsers(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/search/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map